/* FSpotPhotosTable.c generated by valac 0.36.6, the Vala compiler
 * generated from FSpotPhotosTable.vala, do not modify */

/* Copyright 2016 Software Freedom Conservancy Inc.
 *
 * This software is licensed under the GNU Lesser General Public License
 * (version 2.1 or later).  See the COPYING file in this distribution.
 */

#include <glib.h>
#include <glib-object.h>
#include <time.h>
#include <gio/gio.h>
#include <stdlib.h>
#include <string.h>
#include <sqlite3.h>
#include <gee.h>


#define DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_ROW (data_imports_fspot_db_fspot_photo_row_get_type ())
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_ROW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_ROW, DataImportsFSpotDbFSpotPhotoRow))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_ROW, DataImportsFSpotDbFSpotPhotoRowClass))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_PHOTO_ROW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_ROW))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_PHOTO_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_ROW))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_ROW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_ROW, DataImportsFSpotDbFSpotPhotoRowClass))

typedef struct _DataImportsFSpotDbFSpotPhotoRow DataImportsFSpotDbFSpotPhotoRow;
typedef struct _DataImportsFSpotDbFSpotPhotoRowClass DataImportsFSpotDbFSpotPhotoRowClass;
typedef struct _DataImportsFSpotDbFSpotPhotoRowPrivate DataImportsFSpotDbFSpotPhotoRowPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))

#define TYPE_IMPORTABLE_DATABASE_TABLE (importable_database_table_get_type ())
#define IMPORTABLE_DATABASE_TABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_IMPORTABLE_DATABASE_TABLE, ImportableDatabaseTable))
#define IMPORTABLE_DATABASE_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_IMPORTABLE_DATABASE_TABLE, ImportableDatabaseTableClass))
#define IS_IMPORTABLE_DATABASE_TABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_IMPORTABLE_DATABASE_TABLE))
#define IS_IMPORTABLE_DATABASE_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_IMPORTABLE_DATABASE_TABLE))
#define IMPORTABLE_DATABASE_TABLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_IMPORTABLE_DATABASE_TABLE, ImportableDatabaseTableClass))

typedef struct _ImportableDatabaseTable ImportableDatabaseTable;
typedef struct _ImportableDatabaseTableClass ImportableDatabaseTableClass;
typedef struct _ImportableDatabaseTablePrivate ImportableDatabaseTablePrivate;

#define DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_DATABASE_TABLE (data_imports_fspot_db_fspot_database_table_get_type ())
#define DATA_IMPORTS_FSPOT_DB_FSPOT_DATABASE_TABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_DATABASE_TABLE, DataImportsFSpotDbFSpotDatabaseTable))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_DATABASE_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_DATABASE_TABLE, DataImportsFSpotDbFSpotDatabaseTableClass))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_DATABASE_TABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_DATABASE_TABLE))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_DATABASE_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_DATABASE_TABLE))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_DATABASE_TABLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_DATABASE_TABLE, DataImportsFSpotDbFSpotDatabaseTableClass))

typedef struct _DataImportsFSpotDbFSpotDatabaseTable DataImportsFSpotDbFSpotDatabaseTable;
typedef struct _DataImportsFSpotDbFSpotDatabaseTableClass DataImportsFSpotDbFSpotDatabaseTableClass;
typedef struct _DataImportsFSpotDbFSpotDatabaseTablePrivate DataImportsFSpotDbFSpotDatabaseTablePrivate;

#define DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_TABLE_BEHAVIOR (data_imports_fspot_db_fspot_table_behavior_get_type ())
#define DATA_IMPORTS_FSPOT_DB_FSPOT_TABLE_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_TABLE_BEHAVIOR, DataImportsFSpotDbFSpotTableBehavior))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_TABLE_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_TABLE_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_TABLE_BEHAVIOR_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_TABLE_BEHAVIOR, DataImportsFSpotDbFSpotTableBehaviorIface))

typedef struct _DataImportsFSpotDbFSpotTableBehavior DataImportsFSpotDbFSpotTableBehavior;
typedef struct _DataImportsFSpotDbFSpotTableBehaviorIface DataImportsFSpotDbFSpotTableBehaviorIface;

#define DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_TABLE (data_imports_fspot_db_fspot_photos_table_get_type ())
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTOS_TABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_TABLE, DataImportsFSpotDbFSpotPhotosTable))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTOS_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_TABLE, DataImportsFSpotDbFSpotPhotosTableClass))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_PHOTOS_TABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_TABLE))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_PHOTOS_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_TABLE))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTOS_TABLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_TABLE, DataImportsFSpotDbFSpotPhotosTableClass))

typedef struct _DataImportsFSpotDbFSpotPhotosTable DataImportsFSpotDbFSpotPhotosTable;
typedef struct _DataImportsFSpotDbFSpotPhotosTableClass DataImportsFSpotDbFSpotPhotosTableClass;
typedef struct _DataImportsFSpotDbFSpotPhotosTablePrivate DataImportsFSpotDbFSpotPhotosTablePrivate;

#define DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_DATABASE_BEHAVIOR (data_imports_fspot_db_fspot_database_behavior_get_type ())
#define DATA_IMPORTS_FSPOT_DB_FSPOT_DATABASE_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_DATABASE_BEHAVIOR, DataImportsFSpotDbFSpotDatabaseBehavior))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_DATABASE_BEHAVIOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_DATABASE_BEHAVIOR, DataImportsFSpotDbFSpotDatabaseBehaviorClass))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_DATABASE_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_DATABASE_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_DATABASE_BEHAVIOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_DATABASE_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_DATABASE_BEHAVIOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_DATABASE_BEHAVIOR, DataImportsFSpotDbFSpotDatabaseBehaviorClass))

typedef struct _DataImportsFSpotDbFSpotDatabaseBehavior DataImportsFSpotDbFSpotDatabaseBehavior;
typedef struct _DataImportsFSpotDbFSpotDatabaseBehaviorClass DataImportsFSpotDbFSpotDatabaseBehaviorClass;
#define _sqlite3_finalize0(var) ((var == NULL) ? NULL : (var = (sqlite3_finalize (var), NULL)))

#define DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V0_BEHAVIOR (data_imports_fspot_db_fspot_photos_v0_behavior_get_type ())
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTOS_V0_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V0_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV0Behavior))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTOS_V0_BEHAVIOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V0_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV0BehaviorClass))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_PHOTOS_V0_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V0_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_PHOTOS_V0_BEHAVIOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V0_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTOS_V0_BEHAVIOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V0_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV0BehaviorClass))

typedef struct _DataImportsFSpotDbFSpotPhotosV0Behavior DataImportsFSpotDbFSpotPhotosV0Behavior;
typedef struct _DataImportsFSpotDbFSpotPhotosV0BehaviorClass DataImportsFSpotDbFSpotPhotosV0BehaviorClass;
typedef struct _DataImportsFSpotDbFSpotPhotosV0BehaviorPrivate DataImportsFSpotDbFSpotPhotosV0BehaviorPrivate;

#define DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V5_BEHAVIOR (data_imports_fspot_db_fspot_photos_v5_behavior_get_type ())
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTOS_V5_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V5_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV5Behavior))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTOS_V5_BEHAVIOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V5_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV5BehaviorClass))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_PHOTOS_V5_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V5_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_PHOTOS_V5_BEHAVIOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V5_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTOS_V5_BEHAVIOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V5_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV5BehaviorClass))

typedef struct _DataImportsFSpotDbFSpotPhotosV5Behavior DataImportsFSpotDbFSpotPhotosV5Behavior;
typedef struct _DataImportsFSpotDbFSpotPhotosV5BehaviorClass DataImportsFSpotDbFSpotPhotosV5BehaviorClass;
typedef struct _DataImportsFSpotDbFSpotPhotosV5BehaviorPrivate DataImportsFSpotDbFSpotPhotosV5BehaviorPrivate;

#define DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V7_BEHAVIOR (data_imports_fspot_db_fspot_photos_v7_behavior_get_type ())
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTOS_V7_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V7_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV7Behavior))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTOS_V7_BEHAVIOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V7_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV7BehaviorClass))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_PHOTOS_V7_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V7_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_PHOTOS_V7_BEHAVIOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V7_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTOS_V7_BEHAVIOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V7_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV7BehaviorClass))

typedef struct _DataImportsFSpotDbFSpotPhotosV7Behavior DataImportsFSpotDbFSpotPhotosV7Behavior;
typedef struct _DataImportsFSpotDbFSpotPhotosV7BehaviorClass DataImportsFSpotDbFSpotPhotosV7BehaviorClass;
typedef struct _DataImportsFSpotDbFSpotPhotosV7BehaviorPrivate DataImportsFSpotDbFSpotPhotosV7BehaviorPrivate;

#define DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V11_BEHAVIOR (data_imports_fspot_db_fspot_photos_v11_behavior_get_type ())
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTOS_V11_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V11_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV11Behavior))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTOS_V11_BEHAVIOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V11_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV11BehaviorClass))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_PHOTOS_V11_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V11_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_PHOTOS_V11_BEHAVIOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V11_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTOS_V11_BEHAVIOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V11_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV11BehaviorClass))

typedef struct _DataImportsFSpotDbFSpotPhotosV11Behavior DataImportsFSpotDbFSpotPhotosV11Behavior;
typedef struct _DataImportsFSpotDbFSpotPhotosV11BehaviorClass DataImportsFSpotDbFSpotPhotosV11BehaviorClass;
typedef struct _DataImportsFSpotDbFSpotPhotosV11BehaviorPrivate DataImportsFSpotDbFSpotPhotosV11BehaviorPrivate;

#define DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V16_BEHAVIOR (data_imports_fspot_db_fspot_photos_v16_behavior_get_type ())
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTOS_V16_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V16_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV16Behavior))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTOS_V16_BEHAVIOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V16_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV16BehaviorClass))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_PHOTOS_V16_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V16_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_PHOTOS_V16_BEHAVIOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V16_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTOS_V16_BEHAVIOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V16_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV16BehaviorClass))

typedef struct _DataImportsFSpotDbFSpotPhotosV16Behavior DataImportsFSpotDbFSpotPhotosV16Behavior;
typedef struct _DataImportsFSpotDbFSpotPhotosV16BehaviorClass DataImportsFSpotDbFSpotPhotosV16BehaviorClass;
typedef struct _DataImportsFSpotDbFSpotPhotosV16BehaviorPrivate DataImportsFSpotDbFSpotPhotosV16BehaviorPrivate;

#define DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V17_BEHAVIOR (data_imports_fspot_db_fspot_photos_v17_behavior_get_type ())
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTOS_V17_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V17_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV17Behavior))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTOS_V17_BEHAVIOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V17_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV17BehaviorClass))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_PHOTOS_V17_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V17_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_PHOTOS_V17_BEHAVIOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V17_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTOS_V17_BEHAVIOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V17_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV17BehaviorClass))

typedef struct _DataImportsFSpotDbFSpotPhotosV17Behavior DataImportsFSpotDbFSpotPhotosV17Behavior;
typedef struct _DataImportsFSpotDbFSpotPhotosV17BehaviorClass DataImportsFSpotDbFSpotPhotosV17BehaviorClass;
typedef struct _DataImportsFSpotDbFSpotPhotosV17BehaviorPrivate DataImportsFSpotDbFSpotPhotosV17BehaviorPrivate;

#define DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V18_BEHAVIOR (data_imports_fspot_db_fspot_photos_v18_behavior_get_type ())
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTOS_V18_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V18_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV18Behavior))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTOS_V18_BEHAVIOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V18_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV18BehaviorClass))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_PHOTOS_V18_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V18_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_PHOTOS_V18_BEHAVIOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V18_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTOS_V18_BEHAVIOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V18_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV18BehaviorClass))

typedef struct _DataImportsFSpotDbFSpotPhotosV18Behavior DataImportsFSpotDbFSpotPhotosV18Behavior;
typedef struct _DataImportsFSpotDbFSpotPhotosV18BehaviorClass DataImportsFSpotDbFSpotPhotosV18BehaviorClass;
typedef struct _DataImportsFSpotDbFSpotPhotosV18BehaviorPrivate DataImportsFSpotDbFSpotPhotosV18BehaviorPrivate;

struct _DataImportsFSpotDbFSpotPhotoRow {
	GObject parent_instance;
	DataImportsFSpotDbFSpotPhotoRowPrivate * priv;
	gint64 photo_id;
	time_t time;
	GFile* base_path;
	gchar* filename;
	gchar* description;
	gint64 roll_id;
	gint64 default_version_id;
	gint rating;
	gchar* md5_sum;
};

struct _DataImportsFSpotDbFSpotPhotoRowClass {
	GObjectClass parent_class;
};

struct _ImportableDatabaseTable {
	GTypeInstance parent_instance;
	volatile int ref_count;
	ImportableDatabaseTablePrivate * priv;
	gchar* table_name;
};

struct _ImportableDatabaseTableClass {
	GTypeClass parent_class;
	void (*finalize) (ImportableDatabaseTable *self);
};

struct _DataImportsFSpotDbFSpotTableBehaviorIface {
	GTypeInterface parent_iface;
	gchar* (*get_table_name) (DataImportsFSpotDbFSpotTableBehavior* self);
	gchar** (*list_columns) (DataImportsFSpotDbFSpotTableBehavior* self, int* result_length1);
	void (*build_row) (DataImportsFSpotDbFSpotTableBehavior* self, sqlite3_stmt* stmt, gpointer* row, gint offset);
};

struct _DataImportsFSpotDbFSpotDatabaseTable {
	ImportableDatabaseTable parent_instance;
	DataImportsFSpotDbFSpotDatabaseTablePrivate * priv;
	sqlite3* fspot_db;
	DataImportsFSpotDbFSpotTableBehavior* behavior;
};

struct _DataImportsFSpotDbFSpotDatabaseTableClass {
	ImportableDatabaseTableClass parent_class;
};

struct _DataImportsFSpotDbFSpotPhotosTable {
	DataImportsFSpotDbFSpotDatabaseTable parent_instance;
	DataImportsFSpotDbFSpotPhotosTablePrivate * priv;
};

struct _DataImportsFSpotDbFSpotPhotosTableClass {
	DataImportsFSpotDbFSpotDatabaseTableClass parent_class;
};

typedef enum  {
	DATABASE_ERROR_ERROR,
	DATABASE_ERROR_BACKING,
	DATABASE_ERROR_MEMORY,
	DATABASE_ERROR_ABORT,
	DATABASE_ERROR_LIMITS,
	DATABASE_ERROR_TYPESPEC
} DatabaseError;
#define DATABASE_ERROR database_error_quark ()
struct _DataImportsFSpotDbFSpotPhotosV0Behavior {
	GObject parent_instance;
	DataImportsFSpotDbFSpotPhotosV0BehaviorPrivate * priv;
};

struct _DataImportsFSpotDbFSpotPhotosV0BehaviorClass {
	GObjectClass parent_class;
};

struct _DataImportsFSpotDbFSpotPhotosV5Behavior {
	GObject parent_instance;
	DataImportsFSpotDbFSpotPhotosV5BehaviorPrivate * priv;
};

struct _DataImportsFSpotDbFSpotPhotosV5BehaviorClass {
	GObjectClass parent_class;
};

struct _DataImportsFSpotDbFSpotPhotosV7Behavior {
	GObject parent_instance;
	DataImportsFSpotDbFSpotPhotosV7BehaviorPrivate * priv;
};

struct _DataImportsFSpotDbFSpotPhotosV7BehaviorClass {
	GObjectClass parent_class;
};

struct _DataImportsFSpotDbFSpotPhotosV11Behavior {
	GObject parent_instance;
	DataImportsFSpotDbFSpotPhotosV11BehaviorPrivate * priv;
};

struct _DataImportsFSpotDbFSpotPhotosV11BehaviorClass {
	GObjectClass parent_class;
};

struct _DataImportsFSpotDbFSpotPhotosV16Behavior {
	GObject parent_instance;
	DataImportsFSpotDbFSpotPhotosV16BehaviorPrivate * priv;
};

struct _DataImportsFSpotDbFSpotPhotosV16BehaviorClass {
	GObjectClass parent_class;
};

struct _DataImportsFSpotDbFSpotPhotosV17Behavior {
	GObject parent_instance;
	DataImportsFSpotDbFSpotPhotosV17BehaviorPrivate * priv;
};

struct _DataImportsFSpotDbFSpotPhotosV17BehaviorClass {
	GObjectClass parent_class;
};

struct _DataImportsFSpotDbFSpotPhotosV18Behavior {
	GObject parent_instance;
	DataImportsFSpotDbFSpotPhotosV18BehaviorPrivate * priv;
};

struct _DataImportsFSpotDbFSpotPhotosV18BehaviorClass {
	GObjectClass parent_class;
};


static gpointer data_imports_fspot_db_fspot_photo_row_parent_class = NULL;
static gpointer data_imports_fspot_db_fspot_photos_table_parent_class = NULL;
static gpointer data_imports_fspot_db_fspot_photos_v0_behavior_parent_class = NULL;
static DataImportsFSpotDbFSpotPhotosV0Behavior* data_imports_fspot_db_fspot_photos_v0_behavior_instance;
static DataImportsFSpotDbFSpotPhotosV0Behavior* data_imports_fspot_db_fspot_photos_v0_behavior_instance = NULL;
static DataImportsFSpotDbFSpotTableBehaviorIface * data_imports_fspot_db_fspot_photos_v0_behavior_data_imports_fspot_db_fspot_table_behavior_parent_iface = NULL;
static gpointer data_imports_fspot_db_fspot_photos_v5_behavior_parent_class = NULL;
static DataImportsFSpotDbFSpotPhotosV5Behavior* data_imports_fspot_db_fspot_photos_v5_behavior_instance;
static DataImportsFSpotDbFSpotPhotosV5Behavior* data_imports_fspot_db_fspot_photos_v5_behavior_instance = NULL;
static DataImportsFSpotDbFSpotTableBehaviorIface * data_imports_fspot_db_fspot_photos_v5_behavior_data_imports_fspot_db_fspot_table_behavior_parent_iface = NULL;
static gpointer data_imports_fspot_db_fspot_photos_v7_behavior_parent_class = NULL;
static DataImportsFSpotDbFSpotPhotosV7Behavior* data_imports_fspot_db_fspot_photos_v7_behavior_instance;
static DataImportsFSpotDbFSpotPhotosV7Behavior* data_imports_fspot_db_fspot_photos_v7_behavior_instance = NULL;
static DataImportsFSpotDbFSpotTableBehaviorIface * data_imports_fspot_db_fspot_photos_v7_behavior_data_imports_fspot_db_fspot_table_behavior_parent_iface = NULL;
static gpointer data_imports_fspot_db_fspot_photos_v11_behavior_parent_class = NULL;
static DataImportsFSpotDbFSpotPhotosV11Behavior* data_imports_fspot_db_fspot_photos_v11_behavior_instance;
static DataImportsFSpotDbFSpotPhotosV11Behavior* data_imports_fspot_db_fspot_photos_v11_behavior_instance = NULL;
static DataImportsFSpotDbFSpotTableBehaviorIface * data_imports_fspot_db_fspot_photos_v11_behavior_data_imports_fspot_db_fspot_table_behavior_parent_iface = NULL;
static gpointer data_imports_fspot_db_fspot_photos_v16_behavior_parent_class = NULL;
static DataImportsFSpotDbFSpotPhotosV16Behavior* data_imports_fspot_db_fspot_photos_v16_behavior_instance;
static DataImportsFSpotDbFSpotPhotosV16Behavior* data_imports_fspot_db_fspot_photos_v16_behavior_instance = NULL;
static DataImportsFSpotDbFSpotTableBehaviorIface * data_imports_fspot_db_fspot_photos_v16_behavior_data_imports_fspot_db_fspot_table_behavior_parent_iface = NULL;
static gpointer data_imports_fspot_db_fspot_photos_v17_behavior_parent_class = NULL;
static DataImportsFSpotDbFSpotPhotosV17Behavior* data_imports_fspot_db_fspot_photos_v17_behavior_instance;
static DataImportsFSpotDbFSpotPhotosV17Behavior* data_imports_fspot_db_fspot_photos_v17_behavior_instance = NULL;
static DataImportsFSpotDbFSpotTableBehaviorIface * data_imports_fspot_db_fspot_photos_v17_behavior_data_imports_fspot_db_fspot_table_behavior_parent_iface = NULL;
static gpointer data_imports_fspot_db_fspot_photos_v18_behavior_parent_class = NULL;
static DataImportsFSpotDbFSpotPhotosV18Behavior* data_imports_fspot_db_fspot_photos_v18_behavior_instance;
static DataImportsFSpotDbFSpotPhotosV18Behavior* data_imports_fspot_db_fspot_photos_v18_behavior_instance = NULL;
static DataImportsFSpotDbFSpotTableBehaviorIface * data_imports_fspot_db_fspot_photos_v18_behavior_data_imports_fspot_db_fspot_table_behavior_parent_iface = NULL;

GType data_imports_fspot_db_fspot_photo_row_get_type (void) G_GNUC_CONST;
enum  {
	DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_ROW_DUMMY_PROPERTY
};
DataImportsFSpotDbFSpotPhotoRow* data_imports_fspot_db_fspot_photo_row_new (void);
DataImportsFSpotDbFSpotPhotoRow* data_imports_fspot_db_fspot_photo_row_construct (GType object_type);
static void data_imports_fspot_db_fspot_photo_row_finalize (GObject * obj);
gpointer importable_database_table_ref (gpointer instance);
void importable_database_table_unref (gpointer instance);
GParamSpec* param_spec_importable_database_table (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_importable_database_table (GValue* value, gpointer v_object);
void value_take_importable_database_table (GValue* value, gpointer v_object);
gpointer value_get_importable_database_table (const GValue* value);
GType importable_database_table_get_type (void) G_GNUC_CONST;
GType data_imports_fspot_db_fspot_database_table_get_type (void) G_GNUC_CONST;
GType data_imports_fspot_db_fspot_table_behavior_get_type (void) G_GNUC_CONST;
GType data_imports_fspot_db_fspot_photos_table_get_type (void) G_GNUC_CONST;
enum  {
	DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTOS_TABLE_DUMMY_PROPERTY
};
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTOS_TABLE_TABLE_NAME "Photos"
GType data_imports_fspot_db_fspot_database_behavior_get_type (void) G_GNUC_CONST;
DataImportsFSpotDbFSpotPhotosTable* data_imports_fspot_db_fspot_photos_table_new (sqlite3* db, DataImportsFSpotDbFSpotDatabaseBehavior* db_behavior);
DataImportsFSpotDbFSpotPhotosTable* data_imports_fspot_db_fspot_photos_table_construct (GType object_type, sqlite3* db, DataImportsFSpotDbFSpotDatabaseBehavior* db_behavior);
DataImportsFSpotDbFSpotDatabaseTable* data_imports_fspot_db_fspot_database_table_construct (GType object_type, GType t_type, GBoxedCopyFunc t_dup_func, GDestroyNotify t_destroy_func, sqlite3* db);
void data_imports_fspot_db_fspot_database_table_set_behavior (DataImportsFSpotDbFSpotDatabaseTable* self, DataImportsFSpotDbFSpotTableBehavior* behavior);
DataImportsFSpotDbFSpotTableBehavior* data_imports_fspot_db_fspot_database_behavior_get_photos_behavior (DataImportsFSpotDbFSpotDatabaseBehavior* self);
GQuark database_error_quark (void);
GeeArrayList* data_imports_fspot_db_fspot_photos_table_get_all (DataImportsFSpotDbFSpotPhotosTable* self, GError** error);
gint data_imports_fspot_db_fspot_database_table_select_all (DataImportsFSpotDbFSpotDatabaseTable* self, sqlite3_stmt* * stmt, GError** error);
void data_imports_fspot_db_fspot_table_behavior_build_row (DataImportsFSpotDbFSpotTableBehavior* self, sqlite3_stmt* stmt, gpointer* row, gint offset);
GType data_imports_fspot_db_fspot_photos_v0_behavior_get_type (void) G_GNUC_CONST;
enum  {
	DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTOS_V0_BEHAVIOR_DUMMY_PROPERTY
};
static DataImportsFSpotDbFSpotPhotosV0Behavior* data_imports_fspot_db_fspot_photos_v0_behavior_new (void);
static DataImportsFSpotDbFSpotPhotosV0Behavior* data_imports_fspot_db_fspot_photos_v0_behavior_construct (GType object_type);
DataImportsFSpotDbFSpotPhotosV0Behavior* data_imports_fspot_db_fspot_photos_v0_behavior_get_instance (void);
static gchar* data_imports_fspot_db_fspot_photos_v0_behavior_real_get_table_name (DataImportsFSpotDbFSpotTableBehavior* base);
static gchar** data_imports_fspot_db_fspot_photos_v0_behavior_real_list_columns (DataImportsFSpotDbFSpotTableBehavior* base, int* result_length1);
static void data_imports_fspot_db_fspot_photos_v0_behavior_real_build_row (DataImportsFSpotDbFSpotTableBehavior* base, sqlite3_stmt* stmt, DataImportsFSpotDbFSpotPhotoRow* * row, gint offset);
#define DATA_IMPORTS_FSPOT_DB_INVALID_ID ((gint64) -1)
static void data_imports_fspot_db_fspot_photos_v0_behavior_finalize (GObject * obj);
GType data_imports_fspot_db_fspot_photos_v5_behavior_get_type (void) G_GNUC_CONST;
enum  {
	DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTOS_V5_BEHAVIOR_DUMMY_PROPERTY
};
static DataImportsFSpotDbFSpotPhotosV5Behavior* data_imports_fspot_db_fspot_photos_v5_behavior_new (void);
static DataImportsFSpotDbFSpotPhotosV5Behavior* data_imports_fspot_db_fspot_photos_v5_behavior_construct (GType object_type);
DataImportsFSpotDbFSpotPhotosV5Behavior* data_imports_fspot_db_fspot_photos_v5_behavior_get_instance (void);
static gchar* data_imports_fspot_db_fspot_photos_v5_behavior_real_get_table_name (DataImportsFSpotDbFSpotTableBehavior* base);
static gchar** data_imports_fspot_db_fspot_photos_v5_behavior_real_list_columns (DataImportsFSpotDbFSpotTableBehavior* base, int* result_length1);
static void data_imports_fspot_db_fspot_photos_v5_behavior_real_build_row (DataImportsFSpotDbFSpotTableBehavior* base, sqlite3_stmt* stmt, DataImportsFSpotDbFSpotPhotoRow* * row, gint offset);
static void data_imports_fspot_db_fspot_photos_v5_behavior_finalize (GObject * obj);
GType data_imports_fspot_db_fspot_photos_v7_behavior_get_type (void) G_GNUC_CONST;
enum  {
	DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTOS_V7_BEHAVIOR_DUMMY_PROPERTY
};
static DataImportsFSpotDbFSpotPhotosV7Behavior* data_imports_fspot_db_fspot_photos_v7_behavior_new (void);
static DataImportsFSpotDbFSpotPhotosV7Behavior* data_imports_fspot_db_fspot_photos_v7_behavior_construct (GType object_type);
DataImportsFSpotDbFSpotPhotosV7Behavior* data_imports_fspot_db_fspot_photos_v7_behavior_get_instance (void);
static gchar* data_imports_fspot_db_fspot_photos_v7_behavior_real_get_table_name (DataImportsFSpotDbFSpotTableBehavior* base);
static gchar** data_imports_fspot_db_fspot_photos_v7_behavior_real_list_columns (DataImportsFSpotDbFSpotTableBehavior* base, int* result_length1);
static void data_imports_fspot_db_fspot_photos_v7_behavior_real_build_row (DataImportsFSpotDbFSpotTableBehavior* base, sqlite3_stmt* stmt, DataImportsFSpotDbFSpotPhotoRow* * row, gint offset);
static void data_imports_fspot_db_fspot_photos_v7_behavior_finalize (GObject * obj);
GType data_imports_fspot_db_fspot_photos_v11_behavior_get_type (void) G_GNUC_CONST;
enum  {
	DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTOS_V11_BEHAVIOR_DUMMY_PROPERTY
};
static DataImportsFSpotDbFSpotPhotosV11Behavior* data_imports_fspot_db_fspot_photos_v11_behavior_new (void);
static DataImportsFSpotDbFSpotPhotosV11Behavior* data_imports_fspot_db_fspot_photos_v11_behavior_construct (GType object_type);
DataImportsFSpotDbFSpotPhotosV11Behavior* data_imports_fspot_db_fspot_photos_v11_behavior_get_instance (void);
static gchar* data_imports_fspot_db_fspot_photos_v11_behavior_real_get_table_name (DataImportsFSpotDbFSpotTableBehavior* base);
static gchar** data_imports_fspot_db_fspot_photos_v11_behavior_real_list_columns (DataImportsFSpotDbFSpotTableBehavior* base, int* result_length1);
static void data_imports_fspot_db_fspot_photos_v11_behavior_real_build_row (DataImportsFSpotDbFSpotTableBehavior* base, sqlite3_stmt* stmt, DataImportsFSpotDbFSpotPhotoRow* * row, gint offset);
static void data_imports_fspot_db_fspot_photos_v11_behavior_finalize (GObject * obj);
GType data_imports_fspot_db_fspot_photos_v16_behavior_get_type (void) G_GNUC_CONST;
enum  {
	DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTOS_V16_BEHAVIOR_DUMMY_PROPERTY
};
static DataImportsFSpotDbFSpotPhotosV16Behavior* data_imports_fspot_db_fspot_photos_v16_behavior_new (void);
static DataImportsFSpotDbFSpotPhotosV16Behavior* data_imports_fspot_db_fspot_photos_v16_behavior_construct (GType object_type);
DataImportsFSpotDbFSpotPhotosV16Behavior* data_imports_fspot_db_fspot_photos_v16_behavior_get_instance (void);
static gchar* data_imports_fspot_db_fspot_photos_v16_behavior_real_get_table_name (DataImportsFSpotDbFSpotTableBehavior* base);
static gchar** data_imports_fspot_db_fspot_photos_v16_behavior_real_list_columns (DataImportsFSpotDbFSpotTableBehavior* base, int* result_length1);
static void data_imports_fspot_db_fspot_photos_v16_behavior_real_build_row (DataImportsFSpotDbFSpotTableBehavior* base, sqlite3_stmt* stmt, DataImportsFSpotDbFSpotPhotoRow* * row, gint offset);
static void data_imports_fspot_db_fspot_photos_v16_behavior_finalize (GObject * obj);
GType data_imports_fspot_db_fspot_photos_v17_behavior_get_type (void) G_GNUC_CONST;
enum  {
	DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTOS_V17_BEHAVIOR_DUMMY_PROPERTY
};
static DataImportsFSpotDbFSpotPhotosV17Behavior* data_imports_fspot_db_fspot_photos_v17_behavior_new (void);
static DataImportsFSpotDbFSpotPhotosV17Behavior* data_imports_fspot_db_fspot_photos_v17_behavior_construct (GType object_type);
DataImportsFSpotDbFSpotPhotosV17Behavior* data_imports_fspot_db_fspot_photos_v17_behavior_get_instance (void);
static gchar* data_imports_fspot_db_fspot_photos_v17_behavior_real_get_table_name (DataImportsFSpotDbFSpotTableBehavior* base);
static gchar** data_imports_fspot_db_fspot_photos_v17_behavior_real_list_columns (DataImportsFSpotDbFSpotTableBehavior* base, int* result_length1);
static void data_imports_fspot_db_fspot_photos_v17_behavior_real_build_row (DataImportsFSpotDbFSpotTableBehavior* base, sqlite3_stmt* stmt, DataImportsFSpotDbFSpotPhotoRow* * row, gint offset);
static void data_imports_fspot_db_fspot_photos_v17_behavior_finalize (GObject * obj);
GType data_imports_fspot_db_fspot_photos_v18_behavior_get_type (void) G_GNUC_CONST;
enum  {
	DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTOS_V18_BEHAVIOR_DUMMY_PROPERTY
};
static DataImportsFSpotDbFSpotPhotosV18Behavior* data_imports_fspot_db_fspot_photos_v18_behavior_new (void);
static DataImportsFSpotDbFSpotPhotosV18Behavior* data_imports_fspot_db_fspot_photos_v18_behavior_construct (GType object_type);
DataImportsFSpotDbFSpotPhotosV18Behavior* data_imports_fspot_db_fspot_photos_v18_behavior_get_instance (void);
static gchar* data_imports_fspot_db_fspot_photos_v18_behavior_real_get_table_name (DataImportsFSpotDbFSpotTableBehavior* base);
static gchar** data_imports_fspot_db_fspot_photos_v18_behavior_real_list_columns (DataImportsFSpotDbFSpotTableBehavior* base, int* result_length1);
static void data_imports_fspot_db_fspot_photos_v18_behavior_real_build_row (DataImportsFSpotDbFSpotTableBehavior* base, sqlite3_stmt* stmt, DataImportsFSpotDbFSpotPhotoRow* * row, gint offset);
static void data_imports_fspot_db_fspot_photos_v18_behavior_finalize (GObject * obj);


DataImportsFSpotDbFSpotPhotoRow* data_imports_fspot_db_fspot_photo_row_construct (GType object_type) {
	DataImportsFSpotDbFSpotPhotoRow * self = NULL;
#line 12 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	self = (DataImportsFSpotDbFSpotPhotoRow*) g_object_new (object_type, NULL);
#line 12 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	return self;
#line 441 "FSpotPhotosTable.c"
}


DataImportsFSpotDbFSpotPhotoRow* data_imports_fspot_db_fspot_photo_row_new (void) {
#line 12 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	return data_imports_fspot_db_fspot_photo_row_construct (DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_ROW);
#line 448 "FSpotPhotosTable.c"
}


static void data_imports_fspot_db_fspot_photo_row_class_init (DataImportsFSpotDbFSpotPhotoRowClass * klass) {
#line 12 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	data_imports_fspot_db_fspot_photo_row_parent_class = g_type_class_peek_parent (klass);
#line 12 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	G_OBJECT_CLASS (klass)->finalize = data_imports_fspot_db_fspot_photo_row_finalize;
#line 457 "FSpotPhotosTable.c"
}


static void data_imports_fspot_db_fspot_photo_row_instance_init (DataImportsFSpotDbFSpotPhotoRow * self) {
}


static void data_imports_fspot_db_fspot_photo_row_finalize (GObject * obj) {
	DataImportsFSpotDbFSpotPhotoRow * self;
#line 12 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_ROW, DataImportsFSpotDbFSpotPhotoRow);
#line 15 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_g_object_unref0 (self->base_path);
#line 16 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_g_free0 (self->filename);
#line 17 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_g_free0 (self->description);
#line 21 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_g_free0 (self->md5_sum);
#line 12 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	G_OBJECT_CLASS (data_imports_fspot_db_fspot_photo_row_parent_class)->finalize (obj);
#line 479 "FSpotPhotosTable.c"
}


/**
 * The value object for the "photos" table, representing a single database row.
 */
GType data_imports_fspot_db_fspot_photo_row_get_type (void) {
	static volatile gsize data_imports_fspot_db_fspot_photo_row_type_id__volatile = 0;
	if (g_once_init_enter (&data_imports_fspot_db_fspot_photo_row_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (DataImportsFSpotDbFSpotPhotoRowClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) data_imports_fspot_db_fspot_photo_row_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (DataImportsFSpotDbFSpotPhotoRow), 0, (GInstanceInitFunc) data_imports_fspot_db_fspot_photo_row_instance_init, NULL };
		GType data_imports_fspot_db_fspot_photo_row_type_id;
		data_imports_fspot_db_fspot_photo_row_type_id = g_type_register_static (G_TYPE_OBJECT, "DataImportsFSpotDbFSpotPhotoRow", &g_define_type_info, 0);
		g_once_init_leave (&data_imports_fspot_db_fspot_photo_row_type_id__volatile, data_imports_fspot_db_fspot_photo_row_type_id);
	}
	return data_imports_fspot_db_fspot_photo_row_type_id__volatile;
}


DataImportsFSpotDbFSpotPhotosTable* data_imports_fspot_db_fspot_photos_table_construct (GType object_type, sqlite3* db, DataImportsFSpotDbFSpotDatabaseBehavior* db_behavior) {
	DataImportsFSpotDbFSpotPhotosTable* self = NULL;
	sqlite3* _tmp0_;
	DataImportsFSpotDbFSpotDatabaseBehavior* _tmp1_;
	DataImportsFSpotDbFSpotTableBehavior* _tmp2_;
	DataImportsFSpotDbFSpotTableBehavior* _tmp3_;
#line 30 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	g_return_val_if_fail (db != NULL, NULL);
#line 30 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	g_return_val_if_fail (DATA_IMPORTS_FSPOT_DB_IS_FSPOT_DATABASE_BEHAVIOR (db_behavior), NULL);
#line 31 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp0_ = db;
#line 31 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	self = (DataImportsFSpotDbFSpotPhotosTable*) data_imports_fspot_db_fspot_database_table_construct (object_type, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_ROW, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, _tmp0_);
#line 32 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp1_ = db_behavior;
#line 32 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp2_ = data_imports_fspot_db_fspot_database_behavior_get_photos_behavior (_tmp1_);
#line 32 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp3_ = _tmp2_;
#line 32 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	data_imports_fspot_db_fspot_database_table_set_behavior (G_TYPE_CHECK_INSTANCE_CAST (self, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_DATABASE_TABLE, DataImportsFSpotDbFSpotDatabaseTable), _tmp3_);
#line 32 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_g_object_unref0 (_tmp3_);
#line 30 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	return self;
#line 524 "FSpotPhotosTable.c"
}


DataImportsFSpotDbFSpotPhotosTable* data_imports_fspot_db_fspot_photos_table_new (sqlite3* db, DataImportsFSpotDbFSpotDatabaseBehavior* db_behavior) {
#line 30 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	return data_imports_fspot_db_fspot_photos_table_construct (DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_TABLE, db, db_behavior);
#line 531 "FSpotPhotosTable.c"
}


GeeArrayList* data_imports_fspot_db_fspot_photos_table_get_all (DataImportsFSpotDbFSpotPhotosTable* self, GError** error) {
	GeeArrayList* result = NULL;
	GeeArrayList* all = NULL;
	GeeArrayList* _tmp0_;
	sqlite3_stmt* stmt = NULL;
	gint res = 0;
	sqlite3_stmt* _tmp1_ = NULL;
	gint _tmp2_;
	GError * _inner_error_ = NULL;
#line 35 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	g_return_val_if_fail (DATA_IMPORTS_FSPOT_DB_IS_FSPOT_PHOTOS_TABLE (self), NULL);
#line 36 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp0_ = gee_array_list_new (DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_ROW, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL);
#line 36 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	all = _tmp0_;
#line 39 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp2_ = data_imports_fspot_db_fspot_database_table_select_all (G_TYPE_CHECK_INSTANCE_CAST (self, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_DATABASE_TABLE, DataImportsFSpotDbFSpotDatabaseTable), &_tmp1_, &_inner_error_);
#line 39 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_sqlite3_finalize0 (stmt);
#line 39 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	stmt = _tmp1_;
#line 39 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	res = _tmp2_;
#line 39 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 39 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		if (_inner_error_->domain == DATABASE_ERROR) {
#line 39 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
			g_propagate_error (error, _inner_error_);
#line 39 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
			_sqlite3_finalize0 (stmt);
#line 39 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
			_g_object_unref0 (all);
#line 39 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
			return NULL;
#line 570 "FSpotPhotosTable.c"
		} else {
#line 39 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
			_sqlite3_finalize0 (stmt);
#line 39 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
			_g_object_unref0 (all);
#line 39 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 39 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
			g_clear_error (&_inner_error_);
#line 39 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
			return NULL;
#line 582 "FSpotPhotosTable.c"
		}
	}
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	while (TRUE) {
#line 587 "FSpotPhotosTable.c"
		gint _tmp3_;
		DataImportsFSpotDbFSpotPhotoRow* row = NULL;
		DataImportsFSpotDbFSpotTableBehavior* _tmp4_;
		gpointer _tmp5_ = NULL;
		DataImportsFSpotDbFSpotPhotoRow* _tmp6_;
		gint _tmp7_;
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp3_ = res;
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		if (!(_tmp3_ == SQLITE_ROW)) {
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
			break;
#line 600 "FSpotPhotosTable.c"
		}
#line 42 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp4_ = G_TYPE_CHECK_INSTANCE_CAST (self, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_DATABASE_TABLE, DataImportsFSpotDbFSpotDatabaseTable)->behavior;
#line 42 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		data_imports_fspot_db_fspot_table_behavior_build_row (_tmp4_, stmt, &_tmp5_, 0);
#line 42 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_g_object_unref0 (row);
#line 42 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		row = _tmp5_;
#line 43 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp6_ = row;
#line 43 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		gee_abstract_collection_add (G_TYPE_CHECK_INSTANCE_CAST (all, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), _tmp6_);
#line 44 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp7_ = sqlite3_step (stmt);
#line 44 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		res = _tmp7_;
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_g_object_unref0 (row);
#line 620 "FSpotPhotosTable.c"
	}
#line 47 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	result = all;
#line 47 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_sqlite3_finalize0 (stmt);
#line 47 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	return result;
#line 628 "FSpotPhotosTable.c"
}


static void data_imports_fspot_db_fspot_photos_table_class_init (DataImportsFSpotDbFSpotPhotosTableClass * klass) {
#line 27 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	data_imports_fspot_db_fspot_photos_table_parent_class = g_type_class_peek_parent (klass);
#line 635 "FSpotPhotosTable.c"
}


static void data_imports_fspot_db_fspot_photos_table_instance_init (DataImportsFSpotDbFSpotPhotosTable * self) {
}


/**
 * This class represents the F-Spot photos table.
 */
GType data_imports_fspot_db_fspot_photos_table_get_type (void) {
	static volatile gsize data_imports_fspot_db_fspot_photos_table_type_id__volatile = 0;
	if (g_once_init_enter (&data_imports_fspot_db_fspot_photos_table_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (DataImportsFSpotDbFSpotPhotosTableClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) data_imports_fspot_db_fspot_photos_table_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (DataImportsFSpotDbFSpotPhotosTable), 0, (GInstanceInitFunc) data_imports_fspot_db_fspot_photos_table_instance_init, NULL };
		GType data_imports_fspot_db_fspot_photos_table_type_id;
		data_imports_fspot_db_fspot_photos_table_type_id = g_type_register_static (DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_DATABASE_TABLE, "DataImportsFSpotDbFSpotPhotosTable", &g_define_type_info, 0);
		g_once_init_leave (&data_imports_fspot_db_fspot_photos_table_type_id__volatile, data_imports_fspot_db_fspot_photos_table_type_id);
	}
	return data_imports_fspot_db_fspot_photos_table_type_id__volatile;
}


static DataImportsFSpotDbFSpotPhotosV0Behavior* data_imports_fspot_db_fspot_photos_v0_behavior_construct (GType object_type) {
	DataImportsFSpotDbFSpotPhotosV0Behavior * self = NULL;
#line 56 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	self = (DataImportsFSpotDbFSpotPhotosV0Behavior*) g_object_new (object_type, NULL);
#line 56 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	return self;
#line 664 "FSpotPhotosTable.c"
}


static DataImportsFSpotDbFSpotPhotosV0Behavior* data_imports_fspot_db_fspot_photos_v0_behavior_new (void) {
#line 56 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	return data_imports_fspot_db_fspot_photos_v0_behavior_construct (DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V0_BEHAVIOR);
#line 671 "FSpotPhotosTable.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 62 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	return self ? g_object_ref (self) : NULL;
#line 678 "FSpotPhotosTable.c"
}


DataImportsFSpotDbFSpotPhotosV0Behavior* data_imports_fspot_db_fspot_photos_v0_behavior_get_instance (void) {
	DataImportsFSpotDbFSpotPhotosV0Behavior* result = NULL;
	DataImportsFSpotDbFSpotPhotosV0Behavior* _tmp0_;
	DataImportsFSpotDbFSpotPhotosV0Behavior* _tmp2_;
	DataImportsFSpotDbFSpotPhotosV0Behavior* _tmp3_;
#line 60 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp0_ = data_imports_fspot_db_fspot_photos_v0_behavior_instance;
#line 60 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	if (_tmp0_ == NULL) {
#line 691 "FSpotPhotosTable.c"
		DataImportsFSpotDbFSpotPhotosV0Behavior* _tmp1_;
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp1_ = data_imports_fspot_db_fspot_photos_v0_behavior_new ();
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_g_object_unref0 (data_imports_fspot_db_fspot_photos_v0_behavior_instance);
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		data_imports_fspot_db_fspot_photos_v0_behavior_instance = _tmp1_;
#line 699 "FSpotPhotosTable.c"
	}
#line 62 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp2_ = data_imports_fspot_db_fspot_photos_v0_behavior_instance;
#line 62 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 62 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	result = _tmp3_;
#line 62 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	return result;
#line 709 "FSpotPhotosTable.c"
}


static gchar* data_imports_fspot_db_fspot_photos_v0_behavior_real_get_table_name (DataImportsFSpotDbFSpotTableBehavior* base) {
	DataImportsFSpotDbFSpotPhotosV0Behavior * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 65 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V0_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV0Behavior);
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp0_ = g_strdup (DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTOS_TABLE_TABLE_NAME);
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	result = _tmp0_;
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	return result;
#line 725 "FSpotPhotosTable.c"
}


static gchar** data_imports_fspot_db_fspot_photos_v0_behavior_real_list_columns (DataImportsFSpotDbFSpotTableBehavior* base, int* result_length1) {
	DataImportsFSpotDbFSpotPhotosV0Behavior * self;
	gchar** result = NULL;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	gchar** _tmp6_;
	gchar** _tmp7_;
	gint _tmp7__length1;
#line 69 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V0_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV0Behavior);
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp0_ = g_strdup ("id");
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp1_ = g_strdup ("time");
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp2_ = g_strdup ("directory_path");
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp3_ = g_strdup ("name");
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp4_ = g_strdup ("description");
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp5_ = g_strdup ("default_version_id");
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp6_ = g_new0 (gchar*, 6 + 1);
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp6_[0] = _tmp0_;
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp6_[1] = _tmp1_;
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp6_[2] = _tmp2_;
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp6_[3] = _tmp3_;
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp6_[4] = _tmp4_;
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp6_[5] = _tmp5_;
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp7_ = _tmp6_;
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp7__length1 = 6;
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	if (result_length1) {
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		*result_length1 = _tmp7__length1;
#line 777 "FSpotPhotosTable.c"
	}
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	result = _tmp7_;
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	return result;
#line 783 "FSpotPhotosTable.c"
}


static void data_imports_fspot_db_fspot_photos_v0_behavior_real_build_row (DataImportsFSpotDbFSpotTableBehavior* base, sqlite3_stmt* stmt, DataImportsFSpotDbFSpotPhotoRow* * row, gint offset) {
	DataImportsFSpotDbFSpotPhotosV0Behavior * self;
	DataImportsFSpotDbFSpotPhotoRow* _vala_row = NULL;
	DataImportsFSpotDbFSpotPhotoRow* _tmp0_;
	DataImportsFSpotDbFSpotPhotoRow* _tmp1_;
	sqlite3_stmt* _tmp2_;
	gint _tmp3_;
	gint64 _tmp4_;
	DataImportsFSpotDbFSpotPhotoRow* _tmp5_;
	sqlite3_stmt* _tmp6_;
	gint _tmp7_;
	gint64 _tmp8_;
	gchar* base_path = NULL;
	sqlite3_stmt* _tmp9_;
	gint _tmp10_;
	const gchar* _tmp11_;
	gchar* _tmp12_;
	gchar* filename = NULL;
	sqlite3_stmt* _tmp13_;
	gint _tmp14_;
	const gchar* _tmp15_;
	gchar* _tmp16_;
	gboolean _tmp17_ = FALSE;
	const gchar* _tmp18_;
	DataImportsFSpotDbFSpotPhotoRow* _tmp26_;
	sqlite3_stmt* _tmp27_;
	gint _tmp28_;
	const gchar* _tmp29_;
	gchar* _tmp30_;
	DataImportsFSpotDbFSpotPhotoRow* _tmp31_;
	DataImportsFSpotDbFSpotPhotoRow* _tmp32_;
	sqlite3_stmt* _tmp33_;
	gint _tmp34_;
	gint64 _tmp35_;
	DataImportsFSpotDbFSpotPhotoRow* _tmp36_;
	DataImportsFSpotDbFSpotPhotoRow* _tmp37_;
	gchar* _tmp38_;
#line 74 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V0_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV0Behavior);
#line 74 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	g_return_if_fail (stmt != NULL);
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp0_ = data_imports_fspot_db_fspot_photo_row_new ();
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_g_object_unref0 (_vala_row);
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_vala_row = _tmp0_;
#line 76 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp1_ = _vala_row;
#line 76 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp2_ = stmt;
#line 76 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp3_ = offset;
#line 76 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp4_ = sqlite3_column_int64 (_tmp2_, _tmp3_ + 0);
#line 76 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp1_->photo_id = _tmp4_;
#line 77 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp5_ = _vala_row;
#line 77 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp6_ = stmt;
#line 77 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp7_ = offset;
#line 77 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp8_ = sqlite3_column_int64 (_tmp6_, _tmp7_ + 1);
#line 77 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp5_->time = (time_t) _tmp8_;
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp9_ = stmt;
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp10_ = offset;
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp11_ = sqlite3_column_text (_tmp9_, _tmp10_ + 2);
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp12_ = g_strdup (_tmp11_);
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	base_path = _tmp12_;
#line 80 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp13_ = stmt;
#line 80 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp14_ = offset;
#line 80 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp15_ = sqlite3_column_text (_tmp13_, _tmp14_ + 3);
#line 80 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp16_ = g_strdup (_tmp15_);
#line 80 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	filename = _tmp16_;
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp18_ = base_path;
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	if (_tmp18_ != NULL) {
#line 878 "FSpotPhotosTable.c"
		const gchar* _tmp19_;
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp19_ = filename;
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp17_ = _tmp19_ != NULL;
#line 884 "FSpotPhotosTable.c"
	} else {
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp17_ = FALSE;
#line 888 "FSpotPhotosTable.c"
	}
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	if (_tmp17_) {
#line 892 "FSpotPhotosTable.c"
		DataImportsFSpotDbFSpotPhotoRow* _tmp20_;
		const gchar* _tmp21_;
		GFile* _tmp22_;
		DataImportsFSpotDbFSpotPhotoRow* _tmp23_;
		const gchar* _tmp24_;
		gchar* _tmp25_;
#line 82 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp20_ = _vala_row;
#line 82 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp21_ = base_path;
#line 82 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp22_ = g_file_new_for_uri (_tmp21_);
#line 82 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_g_object_unref0 (_tmp20_->base_path);
#line 82 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp20_->base_path = _tmp22_;
#line 83 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp23_ = _vala_row;
#line 83 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp24_ = filename;
#line 83 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp25_ = g_strdup (_tmp24_);
#line 83 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_g_free0 (_tmp23_->filename);
#line 83 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp23_->filename = _tmp25_;
#line 919 "FSpotPhotosTable.c"
	}
#line 86 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp26_ = _vala_row;
#line 86 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp27_ = stmt;
#line 86 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp28_ = offset;
#line 86 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp29_ = sqlite3_column_text (_tmp27_, _tmp28_ + 4);
#line 86 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp30_ = g_strdup (_tmp29_);
#line 86 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_g_free0 (_tmp26_->description);
#line 86 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp26_->description = _tmp30_;
#line 87 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp31_ = _vala_row;
#line 87 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp31_->roll_id = DATA_IMPORTS_FSPOT_DB_INVALID_ID;
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp32_ = _vala_row;
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp33_ = stmt;
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp34_ = offset;
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp35_ = sqlite3_column_int64 (_tmp33_, _tmp34_ + 5);
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp32_->default_version_id = _tmp35_;
#line 89 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp36_ = _vala_row;
#line 89 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp36_->rating = 0;
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp37_ = _vala_row;
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp38_ = g_strdup ("");
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_g_free0 (_tmp37_->md5_sum);
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp37_->md5_sum = _tmp38_;
#line 74 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_g_free0 (filename);
#line 74 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_g_free0 (base_path);
#line 74 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	if (row) {
#line 74 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		*row = _vala_row;
#line 969 "FSpotPhotosTable.c"
	} else {
#line 74 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_g_object_unref0 (_vala_row);
#line 973 "FSpotPhotosTable.c"
	}
}


static void data_imports_fspot_db_fspot_photos_v0_behavior_class_init (DataImportsFSpotDbFSpotPhotosV0BehaviorClass * klass) {
#line 53 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	data_imports_fspot_db_fspot_photos_v0_behavior_parent_class = g_type_class_peek_parent (klass);
#line 53 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	G_OBJECT_CLASS (klass)->finalize = data_imports_fspot_db_fspot_photos_v0_behavior_finalize;
#line 983 "FSpotPhotosTable.c"
}


static void data_imports_fspot_db_fspot_photos_v0_behavior_data_imports_fspot_db_fspot_table_behavior_interface_init (DataImportsFSpotDbFSpotTableBehaviorIface * iface) {
#line 53 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	data_imports_fspot_db_fspot_photos_v0_behavior_data_imports_fspot_db_fspot_table_behavior_parent_iface = g_type_interface_peek_parent (iface);
#line 53 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	iface->get_table_name = (gchar* (*) (DataImportsFSpotDbFSpotTableBehavior *)) data_imports_fspot_db_fspot_photos_v0_behavior_real_get_table_name;
#line 53 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	iface->list_columns = (gchar** (*) (DataImportsFSpotDbFSpotTableBehavior *, int*)) data_imports_fspot_db_fspot_photos_v0_behavior_real_list_columns;
#line 53 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	iface->build_row = (void (*) (DataImportsFSpotDbFSpotTableBehavior *, sqlite3_stmt*, gpointer*, gint)) data_imports_fspot_db_fspot_photos_v0_behavior_real_build_row;
#line 996 "FSpotPhotosTable.c"
}


static void data_imports_fspot_db_fspot_photos_v0_behavior_instance_init (DataImportsFSpotDbFSpotPhotosV0Behavior * self) {
}


static void data_imports_fspot_db_fspot_photos_v0_behavior_finalize (GObject * obj) {
	DataImportsFSpotDbFSpotPhotosV0Behavior * self;
#line 53 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V0_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV0Behavior);
#line 53 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	G_OBJECT_CLASS (data_imports_fspot_db_fspot_photos_v0_behavior_parent_class)->finalize (obj);
#line 1010 "FSpotPhotosTable.c"
}


GType data_imports_fspot_db_fspot_photos_v0_behavior_get_type (void) {
	static volatile gsize data_imports_fspot_db_fspot_photos_v0_behavior_type_id__volatile = 0;
	if (g_once_init_enter (&data_imports_fspot_db_fspot_photos_v0_behavior_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (DataImportsFSpotDbFSpotPhotosV0BehaviorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) data_imports_fspot_db_fspot_photos_v0_behavior_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (DataImportsFSpotDbFSpotPhotosV0Behavior), 0, (GInstanceInitFunc) data_imports_fspot_db_fspot_photos_v0_behavior_instance_init, NULL };
		static const GInterfaceInfo data_imports_fspot_db_fspot_table_behavior_info = { (GInterfaceInitFunc) data_imports_fspot_db_fspot_photos_v0_behavior_data_imports_fspot_db_fspot_table_behavior_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType data_imports_fspot_db_fspot_photos_v0_behavior_type_id;
		data_imports_fspot_db_fspot_photos_v0_behavior_type_id = g_type_register_static (G_TYPE_OBJECT, "DataImportsFSpotDbFSpotPhotosV0Behavior", &g_define_type_info, 0);
		g_type_add_interface_static (data_imports_fspot_db_fspot_photos_v0_behavior_type_id, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_TABLE_BEHAVIOR, &data_imports_fspot_db_fspot_table_behavior_info);
		g_once_init_leave (&data_imports_fspot_db_fspot_photos_v0_behavior_type_id__volatile, data_imports_fspot_db_fspot_photos_v0_behavior_type_id);
	}
	return data_imports_fspot_db_fspot_photos_v0_behavior_type_id__volatile;
}


static DataImportsFSpotDbFSpotPhotosV5Behavior* data_imports_fspot_db_fspot_photos_v5_behavior_construct (GType object_type) {
	DataImportsFSpotDbFSpotPhotosV5Behavior * self = NULL;
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	self = (DataImportsFSpotDbFSpotPhotosV5Behavior*) g_object_new (object_type, NULL);
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	return self;
#line 1034 "FSpotPhotosTable.c"
}


static DataImportsFSpotDbFSpotPhotosV5Behavior* data_imports_fspot_db_fspot_photos_v5_behavior_new (void) {
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	return data_imports_fspot_db_fspot_photos_v5_behavior_construct (DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V5_BEHAVIOR);
#line 1041 "FSpotPhotosTable.c"
}


DataImportsFSpotDbFSpotPhotosV5Behavior* data_imports_fspot_db_fspot_photos_v5_behavior_get_instance (void) {
	DataImportsFSpotDbFSpotPhotosV5Behavior* result = NULL;
	DataImportsFSpotDbFSpotPhotosV5Behavior* _tmp0_;
	DataImportsFSpotDbFSpotPhotosV5Behavior* _tmp2_;
	DataImportsFSpotDbFSpotPhotosV5Behavior* _tmp3_;
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp0_ = data_imports_fspot_db_fspot_photos_v5_behavior_instance;
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	if (_tmp0_ == NULL) {
#line 1054 "FSpotPhotosTable.c"
		DataImportsFSpotDbFSpotPhotosV5Behavior* _tmp1_;
#line 105 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp1_ = data_imports_fspot_db_fspot_photos_v5_behavior_new ();
#line 105 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_g_object_unref0 (data_imports_fspot_db_fspot_photos_v5_behavior_instance);
#line 105 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		data_imports_fspot_db_fspot_photos_v5_behavior_instance = _tmp1_;
#line 1062 "FSpotPhotosTable.c"
	}
#line 106 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp2_ = data_imports_fspot_db_fspot_photos_v5_behavior_instance;
#line 106 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 106 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	result = _tmp3_;
#line 106 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	return result;
#line 1072 "FSpotPhotosTable.c"
}


static gchar* data_imports_fspot_db_fspot_photos_v5_behavior_real_get_table_name (DataImportsFSpotDbFSpotTableBehavior* base) {
	DataImportsFSpotDbFSpotPhotosV5Behavior * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 109 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V5_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV5Behavior);
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp0_ = g_strdup (DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTOS_TABLE_TABLE_NAME);
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	result = _tmp0_;
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	return result;
#line 1088 "FSpotPhotosTable.c"
}


static gchar** data_imports_fspot_db_fspot_photos_v5_behavior_real_list_columns (DataImportsFSpotDbFSpotTableBehavior* base, int* result_length1) {
	DataImportsFSpotDbFSpotPhotosV5Behavior * self;
	gchar** result = NULL;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	gchar** _tmp7_;
	gchar** _tmp8_;
	gint _tmp8__length1;
#line 113 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V5_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV5Behavior);
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp0_ = g_strdup ("id");
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp1_ = g_strdup ("time");
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp2_ = g_strdup ("directory_path");
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp3_ = g_strdup ("name");
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp4_ = g_strdup ("description");
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp5_ = g_strdup ("roll_id");
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp6_ = g_strdup ("default_version_id");
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp7_ = g_new0 (gchar*, 7 + 1);
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp7_[0] = _tmp0_;
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp7_[1] = _tmp1_;
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp7_[2] = _tmp2_;
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp7_[3] = _tmp3_;
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp7_[4] = _tmp4_;
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp7_[5] = _tmp5_;
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp7_[6] = _tmp6_;
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp8_ = _tmp7_;
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp8__length1 = 7;
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	if (result_length1) {
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		*result_length1 = _tmp8__length1;
#line 1145 "FSpotPhotosTable.c"
	}
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	result = _tmp8_;
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	return result;
#line 1151 "FSpotPhotosTable.c"
}


static void data_imports_fspot_db_fspot_photos_v5_behavior_real_build_row (DataImportsFSpotDbFSpotTableBehavior* base, sqlite3_stmt* stmt, DataImportsFSpotDbFSpotPhotoRow* * row, gint offset) {
	DataImportsFSpotDbFSpotPhotosV5Behavior * self;
	DataImportsFSpotDbFSpotPhotoRow* _vala_row = NULL;
	DataImportsFSpotDbFSpotPhotoRow* _tmp0_;
	DataImportsFSpotDbFSpotPhotoRow* _tmp1_;
	sqlite3_stmt* _tmp2_;
	gint _tmp3_;
	gint64 _tmp4_;
	DataImportsFSpotDbFSpotPhotoRow* _tmp5_;
	sqlite3_stmt* _tmp6_;
	gint _tmp7_;
	gint64 _tmp8_;
	gchar* base_path = NULL;
	sqlite3_stmt* _tmp9_;
	gint _tmp10_;
	const gchar* _tmp11_;
	gchar* _tmp12_;
	gchar* filename = NULL;
	sqlite3_stmt* _tmp13_;
	gint _tmp14_;
	const gchar* _tmp15_;
	gchar* _tmp16_;
	gboolean _tmp17_ = FALSE;
	const gchar* _tmp18_;
	DataImportsFSpotDbFSpotPhotoRow* _tmp26_;
	sqlite3_stmt* _tmp27_;
	gint _tmp28_;
	const gchar* _tmp29_;
	gchar* _tmp30_;
	DataImportsFSpotDbFSpotPhotoRow* _tmp31_;
	sqlite3_stmt* _tmp32_;
	gint _tmp33_;
	gint64 _tmp34_;
	DataImportsFSpotDbFSpotPhotoRow* _tmp35_;
	sqlite3_stmt* _tmp36_;
	gint _tmp37_;
	gint64 _tmp38_;
	DataImportsFSpotDbFSpotPhotoRow* _tmp39_;
	DataImportsFSpotDbFSpotPhotoRow* _tmp40_;
	gchar* _tmp41_;
#line 118 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V5_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV5Behavior);
#line 118 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	g_return_if_fail (stmt != NULL);
#line 119 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp0_ = data_imports_fspot_db_fspot_photo_row_new ();
#line 119 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_g_object_unref0 (_vala_row);
#line 119 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_vala_row = _tmp0_;
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp1_ = _vala_row;
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp2_ = stmt;
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp3_ = offset;
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp4_ = sqlite3_column_int64 (_tmp2_, _tmp3_ + 0);
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp1_->photo_id = _tmp4_;
#line 121 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp5_ = _vala_row;
#line 121 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp6_ = stmt;
#line 121 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp7_ = offset;
#line 121 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp8_ = sqlite3_column_int64 (_tmp6_, _tmp7_ + 1);
#line 121 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp5_->time = (time_t) _tmp8_;
#line 123 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp9_ = stmt;
#line 123 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp10_ = offset;
#line 123 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp11_ = sqlite3_column_text (_tmp9_, _tmp10_ + 2);
#line 123 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp12_ = g_strdup (_tmp11_);
#line 123 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	base_path = _tmp12_;
#line 124 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp13_ = stmt;
#line 124 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp14_ = offset;
#line 124 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp15_ = sqlite3_column_text (_tmp13_, _tmp14_ + 3);
#line 124 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp16_ = g_strdup (_tmp15_);
#line 124 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	filename = _tmp16_;
#line 125 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp18_ = base_path;
#line 125 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	if (_tmp18_ != NULL) {
#line 1249 "FSpotPhotosTable.c"
		const gchar* _tmp19_;
#line 125 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp19_ = filename;
#line 125 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp17_ = _tmp19_ != NULL;
#line 1255 "FSpotPhotosTable.c"
	} else {
#line 125 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp17_ = FALSE;
#line 1259 "FSpotPhotosTable.c"
	}
#line 125 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	if (_tmp17_) {
#line 1263 "FSpotPhotosTable.c"
		DataImportsFSpotDbFSpotPhotoRow* _tmp20_;
		const gchar* _tmp21_;
		GFile* _tmp22_;
		DataImportsFSpotDbFSpotPhotoRow* _tmp23_;
		const gchar* _tmp24_;
		gchar* _tmp25_;
#line 126 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp20_ = _vala_row;
#line 126 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp21_ = base_path;
#line 126 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp22_ = g_file_new_for_uri (_tmp21_);
#line 126 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_g_object_unref0 (_tmp20_->base_path);
#line 126 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp20_->base_path = _tmp22_;
#line 127 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp23_ = _vala_row;
#line 127 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp24_ = filename;
#line 127 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp25_ = g_strdup (_tmp24_);
#line 127 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_g_free0 (_tmp23_->filename);
#line 127 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp23_->filename = _tmp25_;
#line 1290 "FSpotPhotosTable.c"
	}
#line 130 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp26_ = _vala_row;
#line 130 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp27_ = stmt;
#line 130 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp28_ = offset;
#line 130 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp29_ = sqlite3_column_text (_tmp27_, _tmp28_ + 4);
#line 130 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp30_ = g_strdup (_tmp29_);
#line 130 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_g_free0 (_tmp26_->description);
#line 130 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp26_->description = _tmp30_;
#line 131 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp31_ = _vala_row;
#line 131 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp32_ = stmt;
#line 131 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp33_ = offset;
#line 131 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp34_ = sqlite3_column_int64 (_tmp32_, _tmp33_ + 5);
#line 131 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp31_->roll_id = _tmp34_;
#line 132 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp35_ = _vala_row;
#line 132 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp36_ = stmt;
#line 132 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp37_ = offset;
#line 132 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp38_ = sqlite3_column_int64 (_tmp36_, _tmp37_ + 6);
#line 132 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp35_->default_version_id = _tmp38_;
#line 133 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp39_ = _vala_row;
#line 133 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp39_->rating = 0;
#line 134 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp40_ = _vala_row;
#line 134 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp41_ = g_strdup ("");
#line 134 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_g_free0 (_tmp40_->md5_sum);
#line 134 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp40_->md5_sum = _tmp41_;
#line 118 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_g_free0 (filename);
#line 118 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_g_free0 (base_path);
#line 118 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	if (row) {
#line 118 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		*row = _vala_row;
#line 1346 "FSpotPhotosTable.c"
	} else {
#line 118 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_g_object_unref0 (_vala_row);
#line 1350 "FSpotPhotosTable.c"
	}
}


static void data_imports_fspot_db_fspot_photos_v5_behavior_class_init (DataImportsFSpotDbFSpotPhotosV5BehaviorClass * klass) {
#line 97 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	data_imports_fspot_db_fspot_photos_v5_behavior_parent_class = g_type_class_peek_parent (klass);
#line 97 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	G_OBJECT_CLASS (klass)->finalize = data_imports_fspot_db_fspot_photos_v5_behavior_finalize;
#line 1360 "FSpotPhotosTable.c"
}


static void data_imports_fspot_db_fspot_photos_v5_behavior_data_imports_fspot_db_fspot_table_behavior_interface_init (DataImportsFSpotDbFSpotTableBehaviorIface * iface) {
#line 97 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	data_imports_fspot_db_fspot_photos_v5_behavior_data_imports_fspot_db_fspot_table_behavior_parent_iface = g_type_interface_peek_parent (iface);
#line 97 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	iface->get_table_name = (gchar* (*) (DataImportsFSpotDbFSpotTableBehavior *)) data_imports_fspot_db_fspot_photos_v5_behavior_real_get_table_name;
#line 97 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	iface->list_columns = (gchar** (*) (DataImportsFSpotDbFSpotTableBehavior *, int*)) data_imports_fspot_db_fspot_photos_v5_behavior_real_list_columns;
#line 97 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	iface->build_row = (void (*) (DataImportsFSpotDbFSpotTableBehavior *, sqlite3_stmt*, gpointer*, gint)) data_imports_fspot_db_fspot_photos_v5_behavior_real_build_row;
#line 1373 "FSpotPhotosTable.c"
}


static void data_imports_fspot_db_fspot_photos_v5_behavior_instance_init (DataImportsFSpotDbFSpotPhotosV5Behavior * self) {
}


static void data_imports_fspot_db_fspot_photos_v5_behavior_finalize (GObject * obj) {
	DataImportsFSpotDbFSpotPhotosV5Behavior * self;
#line 97 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V5_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV5Behavior);
#line 97 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	G_OBJECT_CLASS (data_imports_fspot_db_fspot_photos_v5_behavior_parent_class)->finalize (obj);
#line 1387 "FSpotPhotosTable.c"
}


GType data_imports_fspot_db_fspot_photos_v5_behavior_get_type (void) {
	static volatile gsize data_imports_fspot_db_fspot_photos_v5_behavior_type_id__volatile = 0;
	if (g_once_init_enter (&data_imports_fspot_db_fspot_photos_v5_behavior_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (DataImportsFSpotDbFSpotPhotosV5BehaviorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) data_imports_fspot_db_fspot_photos_v5_behavior_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (DataImportsFSpotDbFSpotPhotosV5Behavior), 0, (GInstanceInitFunc) data_imports_fspot_db_fspot_photos_v5_behavior_instance_init, NULL };
		static const GInterfaceInfo data_imports_fspot_db_fspot_table_behavior_info = { (GInterfaceInitFunc) data_imports_fspot_db_fspot_photos_v5_behavior_data_imports_fspot_db_fspot_table_behavior_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType data_imports_fspot_db_fspot_photos_v5_behavior_type_id;
		data_imports_fspot_db_fspot_photos_v5_behavior_type_id = g_type_register_static (G_TYPE_OBJECT, "DataImportsFSpotDbFSpotPhotosV5Behavior", &g_define_type_info, 0);
		g_type_add_interface_static (data_imports_fspot_db_fspot_photos_v5_behavior_type_id, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_TABLE_BEHAVIOR, &data_imports_fspot_db_fspot_table_behavior_info);
		g_once_init_leave (&data_imports_fspot_db_fspot_photos_v5_behavior_type_id__volatile, data_imports_fspot_db_fspot_photos_v5_behavior_type_id);
	}
	return data_imports_fspot_db_fspot_photos_v5_behavior_type_id__volatile;
}


static DataImportsFSpotDbFSpotPhotosV7Behavior* data_imports_fspot_db_fspot_photos_v7_behavior_construct (GType object_type) {
	DataImportsFSpotDbFSpotPhotosV7Behavior * self = NULL;
#line 145 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	self = (DataImportsFSpotDbFSpotPhotosV7Behavior*) g_object_new (object_type, NULL);
#line 145 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	return self;
#line 1411 "FSpotPhotosTable.c"
}


static DataImportsFSpotDbFSpotPhotosV7Behavior* data_imports_fspot_db_fspot_photos_v7_behavior_new (void) {
#line 145 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	return data_imports_fspot_db_fspot_photos_v7_behavior_construct (DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V7_BEHAVIOR);
#line 1418 "FSpotPhotosTable.c"
}


DataImportsFSpotDbFSpotPhotosV7Behavior* data_imports_fspot_db_fspot_photos_v7_behavior_get_instance (void) {
	DataImportsFSpotDbFSpotPhotosV7Behavior* result = NULL;
	DataImportsFSpotDbFSpotPhotosV7Behavior* _tmp0_;
	DataImportsFSpotDbFSpotPhotosV7Behavior* _tmp2_;
	DataImportsFSpotDbFSpotPhotosV7Behavior* _tmp3_;
#line 149 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp0_ = data_imports_fspot_db_fspot_photos_v7_behavior_instance;
#line 149 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	if (_tmp0_ == NULL) {
#line 1431 "FSpotPhotosTable.c"
		DataImportsFSpotDbFSpotPhotosV7Behavior* _tmp1_;
#line 150 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp1_ = data_imports_fspot_db_fspot_photos_v7_behavior_new ();
#line 150 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_g_object_unref0 (data_imports_fspot_db_fspot_photos_v7_behavior_instance);
#line 150 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		data_imports_fspot_db_fspot_photos_v7_behavior_instance = _tmp1_;
#line 1439 "FSpotPhotosTable.c"
	}
#line 151 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp2_ = data_imports_fspot_db_fspot_photos_v7_behavior_instance;
#line 151 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 151 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	result = _tmp3_;
#line 151 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	return result;
#line 1449 "FSpotPhotosTable.c"
}


static gchar* data_imports_fspot_db_fspot_photos_v7_behavior_real_get_table_name (DataImportsFSpotDbFSpotTableBehavior* base) {
	DataImportsFSpotDbFSpotPhotosV7Behavior * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 154 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V7_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV7Behavior);
#line 155 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp0_ = g_strdup (DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTOS_TABLE_TABLE_NAME);
#line 155 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	result = _tmp0_;
#line 155 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	return result;
#line 1465 "FSpotPhotosTable.c"
}


static gchar** data_imports_fspot_db_fspot_photos_v7_behavior_real_list_columns (DataImportsFSpotDbFSpotTableBehavior* base, int* result_length1) {
	DataImportsFSpotDbFSpotPhotosV7Behavior * self;
	gchar** result = NULL;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	gchar** _tmp6_;
	gchar** _tmp7_;
	gint _tmp7__length1;
#line 158 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V7_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV7Behavior);
#line 159 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp0_ = g_strdup ("id");
#line 159 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp1_ = g_strdup ("time");
#line 159 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp2_ = g_strdup ("uri");
#line 159 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp3_ = g_strdup ("description");
#line 159 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp4_ = g_strdup ("roll_id");
#line 159 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp5_ = g_strdup ("default_version_id");
#line 159 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp6_ = g_new0 (gchar*, 6 + 1);
#line 159 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp6_[0] = _tmp0_;
#line 159 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp6_[1] = _tmp1_;
#line 159 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp6_[2] = _tmp2_;
#line 159 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp6_[3] = _tmp3_;
#line 159 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp6_[4] = _tmp4_;
#line 159 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp6_[5] = _tmp5_;
#line 159 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp7_ = _tmp6_;
#line 159 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp7__length1 = 6;
#line 159 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	if (result_length1) {
#line 159 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		*result_length1 = _tmp7__length1;
#line 1517 "FSpotPhotosTable.c"
	}
#line 159 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	result = _tmp7_;
#line 159 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	return result;
#line 1523 "FSpotPhotosTable.c"
}


static void data_imports_fspot_db_fspot_photos_v7_behavior_real_build_row (DataImportsFSpotDbFSpotTableBehavior* base, sqlite3_stmt* stmt, DataImportsFSpotDbFSpotPhotoRow* * row, gint offset) {
	DataImportsFSpotDbFSpotPhotosV7Behavior * self;
	DataImportsFSpotDbFSpotPhotoRow* _vala_row = NULL;
	DataImportsFSpotDbFSpotPhotoRow* _tmp0_;
	DataImportsFSpotDbFSpotPhotoRow* _tmp1_;
	sqlite3_stmt* _tmp2_;
	gint _tmp3_;
	gint64 _tmp4_;
	DataImportsFSpotDbFSpotPhotoRow* _tmp5_;
	sqlite3_stmt* _tmp6_;
	gint _tmp7_;
	gint64 _tmp8_;
	gchar* full_path = NULL;
	sqlite3_stmt* _tmp9_;
	gint _tmp10_;
	const gchar* _tmp11_;
	gchar* _tmp12_;
	const gchar* _tmp13_;
	DataImportsFSpotDbFSpotPhotoRow* _tmp22_;
	sqlite3_stmt* _tmp23_;
	gint _tmp24_;
	const gchar* _tmp25_;
	gchar* _tmp26_;
	DataImportsFSpotDbFSpotPhotoRow* _tmp27_;
	sqlite3_stmt* _tmp28_;
	gint _tmp29_;
	gint64 _tmp30_;
	DataImportsFSpotDbFSpotPhotoRow* _tmp31_;
	sqlite3_stmt* _tmp32_;
	gint _tmp33_;
	gint64 _tmp34_;
	DataImportsFSpotDbFSpotPhotoRow* _tmp35_;
	DataImportsFSpotDbFSpotPhotoRow* _tmp36_;
	gchar* _tmp37_;
#line 163 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V7_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV7Behavior);
#line 163 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	g_return_if_fail (stmt != NULL);
#line 164 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp0_ = data_imports_fspot_db_fspot_photo_row_new ();
#line 164 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_g_object_unref0 (_vala_row);
#line 164 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_vala_row = _tmp0_;
#line 165 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp1_ = _vala_row;
#line 165 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp2_ = stmt;
#line 165 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp3_ = offset;
#line 165 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp4_ = sqlite3_column_int64 (_tmp2_, _tmp3_ + 0);
#line 165 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp1_->photo_id = _tmp4_;
#line 166 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp5_ = _vala_row;
#line 166 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp6_ = stmt;
#line 166 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp7_ = offset;
#line 166 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp8_ = sqlite3_column_int64 (_tmp6_, _tmp7_ + 1);
#line 166 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp5_->time = (time_t) _tmp8_;
#line 168 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp9_ = stmt;
#line 168 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp10_ = offset;
#line 168 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp11_ = sqlite3_column_text (_tmp9_, _tmp10_ + 2);
#line 168 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp12_ = g_strdup (_tmp11_);
#line 168 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	full_path = _tmp12_;
#line 169 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp13_ = full_path;
#line 169 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	if (_tmp13_ != NULL) {
#line 1605 "FSpotPhotosTable.c"
		GFile* uri = NULL;
		const gchar* _tmp14_;
		GFile* _tmp15_;
		DataImportsFSpotDbFSpotPhotoRow* _tmp16_;
		GFile* _tmp17_;
		GFile* _tmp18_;
		DataImportsFSpotDbFSpotPhotoRow* _tmp19_;
		GFile* _tmp20_;
		gchar* _tmp21_;
#line 170 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp14_ = full_path;
#line 170 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp15_ = g_file_new_for_uri (_tmp14_);
#line 170 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		uri = _tmp15_;
#line 171 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp16_ = _vala_row;
#line 171 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp17_ = uri;
#line 171 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp18_ = g_file_get_parent (_tmp17_);
#line 171 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_g_object_unref0 (_tmp16_->base_path);
#line 171 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp16_->base_path = _tmp18_;
#line 172 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp19_ = _vala_row;
#line 172 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp20_ = uri;
#line 172 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp21_ = g_file_get_basename (_tmp20_);
#line 172 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_g_free0 (_tmp19_->filename);
#line 172 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp19_->filename = _tmp21_;
#line 169 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_g_object_unref0 (uri);
#line 1643 "FSpotPhotosTable.c"
	}
#line 175 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp22_ = _vala_row;
#line 175 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp23_ = stmt;
#line 175 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp24_ = offset;
#line 175 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp25_ = sqlite3_column_text (_tmp23_, _tmp24_ + 3);
#line 175 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp26_ = g_strdup (_tmp25_);
#line 175 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_g_free0 (_tmp22_->description);
#line 175 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp22_->description = _tmp26_;
#line 176 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp27_ = _vala_row;
#line 176 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp28_ = stmt;
#line 176 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp29_ = offset;
#line 176 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp30_ = sqlite3_column_int64 (_tmp28_, _tmp29_ + 4);
#line 176 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp27_->roll_id = _tmp30_;
#line 177 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp31_ = _vala_row;
#line 177 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp32_ = stmt;
#line 177 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp33_ = offset;
#line 177 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp34_ = sqlite3_column_int64 (_tmp32_, _tmp33_ + 5);
#line 177 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp31_->default_version_id = _tmp34_;
#line 178 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp35_ = _vala_row;
#line 178 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp35_->rating = 0;
#line 179 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp36_ = _vala_row;
#line 179 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp37_ = g_strdup ("");
#line 179 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_g_free0 (_tmp36_->md5_sum);
#line 179 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp36_->md5_sum = _tmp37_;
#line 163 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_g_free0 (full_path);
#line 163 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	if (row) {
#line 163 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		*row = _vala_row;
#line 1697 "FSpotPhotosTable.c"
	} else {
#line 163 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_g_object_unref0 (_vala_row);
#line 1701 "FSpotPhotosTable.c"
	}
}


static void data_imports_fspot_db_fspot_photos_v7_behavior_class_init (DataImportsFSpotDbFSpotPhotosV7BehaviorClass * klass) {
#line 142 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	data_imports_fspot_db_fspot_photos_v7_behavior_parent_class = g_type_class_peek_parent (klass);
#line 142 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	G_OBJECT_CLASS (klass)->finalize = data_imports_fspot_db_fspot_photos_v7_behavior_finalize;
#line 1711 "FSpotPhotosTable.c"
}


static void data_imports_fspot_db_fspot_photos_v7_behavior_data_imports_fspot_db_fspot_table_behavior_interface_init (DataImportsFSpotDbFSpotTableBehaviorIface * iface) {
#line 142 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	data_imports_fspot_db_fspot_photos_v7_behavior_data_imports_fspot_db_fspot_table_behavior_parent_iface = g_type_interface_peek_parent (iface);
#line 142 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	iface->get_table_name = (gchar* (*) (DataImportsFSpotDbFSpotTableBehavior *)) data_imports_fspot_db_fspot_photos_v7_behavior_real_get_table_name;
#line 142 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	iface->list_columns = (gchar** (*) (DataImportsFSpotDbFSpotTableBehavior *, int*)) data_imports_fspot_db_fspot_photos_v7_behavior_real_list_columns;
#line 142 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	iface->build_row = (void (*) (DataImportsFSpotDbFSpotTableBehavior *, sqlite3_stmt*, gpointer*, gint)) data_imports_fspot_db_fspot_photos_v7_behavior_real_build_row;
#line 1724 "FSpotPhotosTable.c"
}


static void data_imports_fspot_db_fspot_photos_v7_behavior_instance_init (DataImportsFSpotDbFSpotPhotosV7Behavior * self) {
}


static void data_imports_fspot_db_fspot_photos_v7_behavior_finalize (GObject * obj) {
	DataImportsFSpotDbFSpotPhotosV7Behavior * self;
#line 142 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V7_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV7Behavior);
#line 142 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	G_OBJECT_CLASS (data_imports_fspot_db_fspot_photos_v7_behavior_parent_class)->finalize (obj);
#line 1738 "FSpotPhotosTable.c"
}


GType data_imports_fspot_db_fspot_photos_v7_behavior_get_type (void) {
	static volatile gsize data_imports_fspot_db_fspot_photos_v7_behavior_type_id__volatile = 0;
	if (g_once_init_enter (&data_imports_fspot_db_fspot_photos_v7_behavior_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (DataImportsFSpotDbFSpotPhotosV7BehaviorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) data_imports_fspot_db_fspot_photos_v7_behavior_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (DataImportsFSpotDbFSpotPhotosV7Behavior), 0, (GInstanceInitFunc) data_imports_fspot_db_fspot_photos_v7_behavior_instance_init, NULL };
		static const GInterfaceInfo data_imports_fspot_db_fspot_table_behavior_info = { (GInterfaceInitFunc) data_imports_fspot_db_fspot_photos_v7_behavior_data_imports_fspot_db_fspot_table_behavior_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType data_imports_fspot_db_fspot_photos_v7_behavior_type_id;
		data_imports_fspot_db_fspot_photos_v7_behavior_type_id = g_type_register_static (G_TYPE_OBJECT, "DataImportsFSpotDbFSpotPhotosV7Behavior", &g_define_type_info, 0);
		g_type_add_interface_static (data_imports_fspot_db_fspot_photos_v7_behavior_type_id, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_TABLE_BEHAVIOR, &data_imports_fspot_db_fspot_table_behavior_info);
		g_once_init_leave (&data_imports_fspot_db_fspot_photos_v7_behavior_type_id__volatile, data_imports_fspot_db_fspot_photos_v7_behavior_type_id);
	}
	return data_imports_fspot_db_fspot_photos_v7_behavior_type_id__volatile;
}


static DataImportsFSpotDbFSpotPhotosV11Behavior* data_imports_fspot_db_fspot_photos_v11_behavior_construct (GType object_type) {
	DataImportsFSpotDbFSpotPhotosV11Behavior * self = NULL;
#line 188 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	self = (DataImportsFSpotDbFSpotPhotosV11Behavior*) g_object_new (object_type, NULL);
#line 188 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	return self;
#line 1762 "FSpotPhotosTable.c"
}


static DataImportsFSpotDbFSpotPhotosV11Behavior* data_imports_fspot_db_fspot_photos_v11_behavior_new (void) {
#line 188 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	return data_imports_fspot_db_fspot_photos_v11_behavior_construct (DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V11_BEHAVIOR);
#line 1769 "FSpotPhotosTable.c"
}


DataImportsFSpotDbFSpotPhotosV11Behavior* data_imports_fspot_db_fspot_photos_v11_behavior_get_instance (void) {
	DataImportsFSpotDbFSpotPhotosV11Behavior* result = NULL;
	DataImportsFSpotDbFSpotPhotosV11Behavior* _tmp0_;
	DataImportsFSpotDbFSpotPhotosV11Behavior* _tmp2_;
	DataImportsFSpotDbFSpotPhotosV11Behavior* _tmp3_;
#line 192 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp0_ = data_imports_fspot_db_fspot_photos_v11_behavior_instance;
#line 192 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	if (_tmp0_ == NULL) {
#line 1782 "FSpotPhotosTable.c"
		DataImportsFSpotDbFSpotPhotosV11Behavior* _tmp1_;
#line 193 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp1_ = data_imports_fspot_db_fspot_photos_v11_behavior_new ();
#line 193 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_g_object_unref0 (data_imports_fspot_db_fspot_photos_v11_behavior_instance);
#line 193 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		data_imports_fspot_db_fspot_photos_v11_behavior_instance = _tmp1_;
#line 1790 "FSpotPhotosTable.c"
	}
#line 194 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp2_ = data_imports_fspot_db_fspot_photos_v11_behavior_instance;
#line 194 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 194 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	result = _tmp3_;
#line 194 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	return result;
#line 1800 "FSpotPhotosTable.c"
}


static gchar* data_imports_fspot_db_fspot_photos_v11_behavior_real_get_table_name (DataImportsFSpotDbFSpotTableBehavior* base) {
	DataImportsFSpotDbFSpotPhotosV11Behavior * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 197 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V11_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV11Behavior);
#line 198 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp0_ = g_strdup (DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTOS_TABLE_TABLE_NAME);
#line 198 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	result = _tmp0_;
#line 198 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	return result;
#line 1816 "FSpotPhotosTable.c"
}


static gchar** data_imports_fspot_db_fspot_photos_v11_behavior_real_list_columns (DataImportsFSpotDbFSpotTableBehavior* base, int* result_length1) {
	DataImportsFSpotDbFSpotPhotosV11Behavior * self;
	gchar** result = NULL;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	gchar** _tmp7_;
	gchar** _tmp8_;
	gint _tmp8__length1;
#line 201 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V11_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV11Behavior);
#line 202 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp0_ = g_strdup ("id");
#line 202 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp1_ = g_strdup ("time");
#line 202 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp2_ = g_strdup ("uri");
#line 202 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp3_ = g_strdup ("description");
#line 202 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp4_ = g_strdup ("roll_id");
#line 202 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp5_ = g_strdup ("default_version_id");
#line 202 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp6_ = g_strdup ("rating");
#line 202 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp7_ = g_new0 (gchar*, 7 + 1);
#line 202 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp7_[0] = _tmp0_;
#line 202 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp7_[1] = _tmp1_;
#line 202 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp7_[2] = _tmp2_;
#line 202 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp7_[3] = _tmp3_;
#line 202 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp7_[4] = _tmp4_;
#line 202 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp7_[5] = _tmp5_;
#line 202 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp7_[6] = _tmp6_;
#line 202 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp8_ = _tmp7_;
#line 202 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp8__length1 = 7;
#line 202 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	if (result_length1) {
#line 202 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		*result_length1 = _tmp8__length1;
#line 1873 "FSpotPhotosTable.c"
	}
#line 202 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	result = _tmp8_;
#line 202 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	return result;
#line 1879 "FSpotPhotosTable.c"
}


static void data_imports_fspot_db_fspot_photos_v11_behavior_real_build_row (DataImportsFSpotDbFSpotTableBehavior* base, sqlite3_stmt* stmt, DataImportsFSpotDbFSpotPhotoRow* * row, gint offset) {
	DataImportsFSpotDbFSpotPhotosV11Behavior * self;
	DataImportsFSpotDbFSpotPhotoRow* _vala_row = NULL;
	DataImportsFSpotDbFSpotPhotoRow* _tmp0_;
	DataImportsFSpotDbFSpotPhotoRow* _tmp1_;
	sqlite3_stmt* _tmp2_;
	gint _tmp3_;
	gint64 _tmp4_;
	DataImportsFSpotDbFSpotPhotoRow* _tmp5_;
	sqlite3_stmt* _tmp6_;
	gint _tmp7_;
	gint64 _tmp8_;
	gchar* full_path = NULL;
	sqlite3_stmt* _tmp9_;
	gint _tmp10_;
	const gchar* _tmp11_;
	gchar* _tmp12_;
	const gchar* _tmp13_;
	DataImportsFSpotDbFSpotPhotoRow* _tmp22_;
	sqlite3_stmt* _tmp23_;
	gint _tmp24_;
	const gchar* _tmp25_;
	gchar* _tmp26_;
	DataImportsFSpotDbFSpotPhotoRow* _tmp27_;
	sqlite3_stmt* _tmp28_;
	gint _tmp29_;
	gint64 _tmp30_;
	DataImportsFSpotDbFSpotPhotoRow* _tmp31_;
	sqlite3_stmt* _tmp32_;
	gint _tmp33_;
	gint64 _tmp34_;
	DataImportsFSpotDbFSpotPhotoRow* _tmp35_;
	sqlite3_stmt* _tmp36_;
	gint _tmp37_;
	gint _tmp38_;
	DataImportsFSpotDbFSpotPhotoRow* _tmp39_;
	gchar* _tmp40_;
#line 206 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V11_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV11Behavior);
#line 206 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	g_return_if_fail (stmt != NULL);
#line 207 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp0_ = data_imports_fspot_db_fspot_photo_row_new ();
#line 207 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_g_object_unref0 (_vala_row);
#line 207 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_vala_row = _tmp0_;
#line 208 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp1_ = _vala_row;
#line 208 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp2_ = stmt;
#line 208 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp3_ = offset;
#line 208 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp4_ = sqlite3_column_int64 (_tmp2_, _tmp3_ + 0);
#line 208 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp1_->photo_id = _tmp4_;
#line 209 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp5_ = _vala_row;
#line 209 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp6_ = stmt;
#line 209 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp7_ = offset;
#line 209 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp8_ = sqlite3_column_int64 (_tmp6_, _tmp7_ + 1);
#line 209 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp5_->time = (time_t) _tmp8_;
#line 211 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp9_ = stmt;
#line 211 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp10_ = offset;
#line 211 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp11_ = sqlite3_column_text (_tmp9_, _tmp10_ + 2);
#line 211 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp12_ = g_strdup (_tmp11_);
#line 211 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	full_path = _tmp12_;
#line 212 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp13_ = full_path;
#line 212 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	if (_tmp13_ != NULL) {
#line 1964 "FSpotPhotosTable.c"
		GFile* uri = NULL;
		const gchar* _tmp14_;
		GFile* _tmp15_;
		DataImportsFSpotDbFSpotPhotoRow* _tmp16_;
		GFile* _tmp17_;
		GFile* _tmp18_;
		DataImportsFSpotDbFSpotPhotoRow* _tmp19_;
		GFile* _tmp20_;
		gchar* _tmp21_;
#line 213 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp14_ = full_path;
#line 213 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp15_ = g_file_new_for_uri (_tmp14_);
#line 213 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		uri = _tmp15_;
#line 214 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp16_ = _vala_row;
#line 214 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp17_ = uri;
#line 214 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp18_ = g_file_get_parent (_tmp17_);
#line 214 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_g_object_unref0 (_tmp16_->base_path);
#line 214 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp16_->base_path = _tmp18_;
#line 215 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp19_ = _vala_row;
#line 215 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp20_ = uri;
#line 215 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp21_ = g_file_get_basename (_tmp20_);
#line 215 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_g_free0 (_tmp19_->filename);
#line 215 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp19_->filename = _tmp21_;
#line 212 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_g_object_unref0 (uri);
#line 2002 "FSpotPhotosTable.c"
	}
#line 218 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp22_ = _vala_row;
#line 218 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp23_ = stmt;
#line 218 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp24_ = offset;
#line 218 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp25_ = sqlite3_column_text (_tmp23_, _tmp24_ + 3);
#line 218 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp26_ = g_strdup (_tmp25_);
#line 218 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_g_free0 (_tmp22_->description);
#line 218 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp22_->description = _tmp26_;
#line 219 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp27_ = _vala_row;
#line 219 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp28_ = stmt;
#line 219 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp29_ = offset;
#line 219 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp30_ = sqlite3_column_int64 (_tmp28_, _tmp29_ + 4);
#line 219 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp27_->roll_id = _tmp30_;
#line 220 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp31_ = _vala_row;
#line 220 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp32_ = stmt;
#line 220 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp33_ = offset;
#line 220 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp34_ = sqlite3_column_int64 (_tmp32_, _tmp33_ + 5);
#line 220 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp31_->default_version_id = _tmp34_;
#line 221 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp35_ = _vala_row;
#line 221 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp36_ = stmt;
#line 221 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp37_ = offset;
#line 221 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp38_ = sqlite3_column_int (_tmp36_, _tmp37_ + 6);
#line 221 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp35_->rating = _tmp38_;
#line 222 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp39_ = _vala_row;
#line 222 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp40_ = g_strdup ("");
#line 222 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_g_free0 (_tmp39_->md5_sum);
#line 222 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp39_->md5_sum = _tmp40_;
#line 206 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_g_free0 (full_path);
#line 206 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	if (row) {
#line 206 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		*row = _vala_row;
#line 2062 "FSpotPhotosTable.c"
	} else {
#line 206 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_g_object_unref0 (_vala_row);
#line 2066 "FSpotPhotosTable.c"
	}
}


static void data_imports_fspot_db_fspot_photos_v11_behavior_class_init (DataImportsFSpotDbFSpotPhotosV11BehaviorClass * klass) {
#line 185 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	data_imports_fspot_db_fspot_photos_v11_behavior_parent_class = g_type_class_peek_parent (klass);
#line 185 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	G_OBJECT_CLASS (klass)->finalize = data_imports_fspot_db_fspot_photos_v11_behavior_finalize;
#line 2076 "FSpotPhotosTable.c"
}


static void data_imports_fspot_db_fspot_photos_v11_behavior_data_imports_fspot_db_fspot_table_behavior_interface_init (DataImportsFSpotDbFSpotTableBehaviorIface * iface) {
#line 185 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	data_imports_fspot_db_fspot_photos_v11_behavior_data_imports_fspot_db_fspot_table_behavior_parent_iface = g_type_interface_peek_parent (iface);
#line 185 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	iface->get_table_name = (gchar* (*) (DataImportsFSpotDbFSpotTableBehavior *)) data_imports_fspot_db_fspot_photos_v11_behavior_real_get_table_name;
#line 185 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	iface->list_columns = (gchar** (*) (DataImportsFSpotDbFSpotTableBehavior *, int*)) data_imports_fspot_db_fspot_photos_v11_behavior_real_list_columns;
#line 185 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	iface->build_row = (void (*) (DataImportsFSpotDbFSpotTableBehavior *, sqlite3_stmt*, gpointer*, gint)) data_imports_fspot_db_fspot_photos_v11_behavior_real_build_row;
#line 2089 "FSpotPhotosTable.c"
}


static void data_imports_fspot_db_fspot_photos_v11_behavior_instance_init (DataImportsFSpotDbFSpotPhotosV11Behavior * self) {
}


static void data_imports_fspot_db_fspot_photos_v11_behavior_finalize (GObject * obj) {
	DataImportsFSpotDbFSpotPhotosV11Behavior * self;
#line 185 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V11_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV11Behavior);
#line 185 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	G_OBJECT_CLASS (data_imports_fspot_db_fspot_photos_v11_behavior_parent_class)->finalize (obj);
#line 2103 "FSpotPhotosTable.c"
}


GType data_imports_fspot_db_fspot_photos_v11_behavior_get_type (void) {
	static volatile gsize data_imports_fspot_db_fspot_photos_v11_behavior_type_id__volatile = 0;
	if (g_once_init_enter (&data_imports_fspot_db_fspot_photos_v11_behavior_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (DataImportsFSpotDbFSpotPhotosV11BehaviorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) data_imports_fspot_db_fspot_photos_v11_behavior_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (DataImportsFSpotDbFSpotPhotosV11Behavior), 0, (GInstanceInitFunc) data_imports_fspot_db_fspot_photos_v11_behavior_instance_init, NULL };
		static const GInterfaceInfo data_imports_fspot_db_fspot_table_behavior_info = { (GInterfaceInitFunc) data_imports_fspot_db_fspot_photos_v11_behavior_data_imports_fspot_db_fspot_table_behavior_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType data_imports_fspot_db_fspot_photos_v11_behavior_type_id;
		data_imports_fspot_db_fspot_photos_v11_behavior_type_id = g_type_register_static (G_TYPE_OBJECT, "DataImportsFSpotDbFSpotPhotosV11Behavior", &g_define_type_info, 0);
		g_type_add_interface_static (data_imports_fspot_db_fspot_photos_v11_behavior_type_id, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_TABLE_BEHAVIOR, &data_imports_fspot_db_fspot_table_behavior_info);
		g_once_init_leave (&data_imports_fspot_db_fspot_photos_v11_behavior_type_id__volatile, data_imports_fspot_db_fspot_photos_v11_behavior_type_id);
	}
	return data_imports_fspot_db_fspot_photos_v11_behavior_type_id__volatile;
}


static DataImportsFSpotDbFSpotPhotosV16Behavior* data_imports_fspot_db_fspot_photos_v16_behavior_construct (GType object_type) {
	DataImportsFSpotDbFSpotPhotosV16Behavior * self = NULL;
#line 231 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	self = (DataImportsFSpotDbFSpotPhotosV16Behavior*) g_object_new (object_type, NULL);
#line 231 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	return self;
#line 2127 "FSpotPhotosTable.c"
}


static DataImportsFSpotDbFSpotPhotosV16Behavior* data_imports_fspot_db_fspot_photos_v16_behavior_new (void) {
#line 231 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	return data_imports_fspot_db_fspot_photos_v16_behavior_construct (DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V16_BEHAVIOR);
#line 2134 "FSpotPhotosTable.c"
}


DataImportsFSpotDbFSpotPhotosV16Behavior* data_imports_fspot_db_fspot_photos_v16_behavior_get_instance (void) {
	DataImportsFSpotDbFSpotPhotosV16Behavior* result = NULL;
	DataImportsFSpotDbFSpotPhotosV16Behavior* _tmp0_;
	DataImportsFSpotDbFSpotPhotosV16Behavior* _tmp2_;
	DataImportsFSpotDbFSpotPhotosV16Behavior* _tmp3_;
#line 235 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp0_ = data_imports_fspot_db_fspot_photos_v16_behavior_instance;
#line 235 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	if (_tmp0_ == NULL) {
#line 2147 "FSpotPhotosTable.c"
		DataImportsFSpotDbFSpotPhotosV16Behavior* _tmp1_;
#line 236 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp1_ = data_imports_fspot_db_fspot_photos_v16_behavior_new ();
#line 236 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_g_object_unref0 (data_imports_fspot_db_fspot_photos_v16_behavior_instance);
#line 236 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		data_imports_fspot_db_fspot_photos_v16_behavior_instance = _tmp1_;
#line 2155 "FSpotPhotosTable.c"
	}
#line 237 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp2_ = data_imports_fspot_db_fspot_photos_v16_behavior_instance;
#line 237 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 237 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	result = _tmp3_;
#line 237 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	return result;
#line 2165 "FSpotPhotosTable.c"
}


static gchar* data_imports_fspot_db_fspot_photos_v16_behavior_real_get_table_name (DataImportsFSpotDbFSpotTableBehavior* base) {
	DataImportsFSpotDbFSpotPhotosV16Behavior * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 240 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V16_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV16Behavior);
#line 241 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp0_ = g_strdup (DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTOS_TABLE_TABLE_NAME);
#line 241 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	result = _tmp0_;
#line 241 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	return result;
#line 2181 "FSpotPhotosTable.c"
}


static gchar** data_imports_fspot_db_fspot_photos_v16_behavior_real_list_columns (DataImportsFSpotDbFSpotTableBehavior* base, int* result_length1) {
	DataImportsFSpotDbFSpotPhotosV16Behavior * self;
	gchar** result = NULL;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	gchar* _tmp7_;
	gchar** _tmp8_;
	gchar** _tmp9_;
	gint _tmp9__length1;
#line 244 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V16_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV16Behavior);
#line 245 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp0_ = g_strdup ("id");
#line 245 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp1_ = g_strdup ("time");
#line 245 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp2_ = g_strdup ("uri");
#line 245 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp3_ = g_strdup ("description");
#line 245 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp4_ = g_strdup ("roll_id");
#line 245 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp5_ = g_strdup ("default_version_id");
#line 245 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp6_ = g_strdup ("rating");
#line 245 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp7_ = g_strdup ("md5_sum");
#line 245 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp8_ = g_new0 (gchar*, 8 + 1);
#line 245 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp8_[0] = _tmp0_;
#line 245 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp8_[1] = _tmp1_;
#line 245 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp8_[2] = _tmp2_;
#line 245 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp8_[3] = _tmp3_;
#line 245 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp8_[4] = _tmp4_;
#line 245 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp8_[5] = _tmp5_;
#line 245 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp8_[6] = _tmp6_;
#line 245 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp8_[7] = _tmp7_;
#line 245 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp9_ = _tmp8_;
#line 245 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp9__length1 = 8;
#line 245 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	if (result_length1) {
#line 245 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		*result_length1 = _tmp9__length1;
#line 2243 "FSpotPhotosTable.c"
	}
#line 245 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	result = _tmp9_;
#line 245 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	return result;
#line 2249 "FSpotPhotosTable.c"
}


static void data_imports_fspot_db_fspot_photos_v16_behavior_real_build_row (DataImportsFSpotDbFSpotTableBehavior* base, sqlite3_stmt* stmt, DataImportsFSpotDbFSpotPhotoRow* * row, gint offset) {
	DataImportsFSpotDbFSpotPhotosV16Behavior * self;
	DataImportsFSpotDbFSpotPhotoRow* _vala_row = NULL;
	DataImportsFSpotDbFSpotPhotoRow* _tmp0_;
	DataImportsFSpotDbFSpotPhotoRow* _tmp1_;
	sqlite3_stmt* _tmp2_;
	gint _tmp3_;
	gint64 _tmp4_;
	DataImportsFSpotDbFSpotPhotoRow* _tmp5_;
	sqlite3_stmt* _tmp6_;
	gint _tmp7_;
	gint64 _tmp8_;
	gchar* full_path = NULL;
	sqlite3_stmt* _tmp9_;
	gint _tmp10_;
	const gchar* _tmp11_;
	gchar* _tmp12_;
	const gchar* _tmp13_;
	DataImportsFSpotDbFSpotPhotoRow* _tmp22_;
	sqlite3_stmt* _tmp23_;
	gint _tmp24_;
	const gchar* _tmp25_;
	gchar* _tmp26_;
	DataImportsFSpotDbFSpotPhotoRow* _tmp27_;
	sqlite3_stmt* _tmp28_;
	gint _tmp29_;
	gint64 _tmp30_;
	DataImportsFSpotDbFSpotPhotoRow* _tmp31_;
	sqlite3_stmt* _tmp32_;
	gint _tmp33_;
	gint64 _tmp34_;
	DataImportsFSpotDbFSpotPhotoRow* _tmp35_;
	sqlite3_stmt* _tmp36_;
	gint _tmp37_;
	gint _tmp38_;
	DataImportsFSpotDbFSpotPhotoRow* _tmp39_;
	sqlite3_stmt* _tmp40_;
	gint _tmp41_;
	const gchar* _tmp42_;
	gchar* _tmp43_;
#line 249 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V16_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV16Behavior);
#line 249 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	g_return_if_fail (stmt != NULL);
#line 250 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp0_ = data_imports_fspot_db_fspot_photo_row_new ();
#line 250 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_g_object_unref0 (_vala_row);
#line 250 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_vala_row = _tmp0_;
#line 251 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp1_ = _vala_row;
#line 251 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp2_ = stmt;
#line 251 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp3_ = offset;
#line 251 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp4_ = sqlite3_column_int64 (_tmp2_, _tmp3_ + 0);
#line 251 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp1_->photo_id = _tmp4_;
#line 252 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp5_ = _vala_row;
#line 252 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp6_ = stmt;
#line 252 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp7_ = offset;
#line 252 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp8_ = sqlite3_column_int64 (_tmp6_, _tmp7_ + 1);
#line 252 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp5_->time = (time_t) _tmp8_;
#line 254 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp9_ = stmt;
#line 254 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp10_ = offset;
#line 254 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp11_ = sqlite3_column_text (_tmp9_, _tmp10_ + 2);
#line 254 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp12_ = g_strdup (_tmp11_);
#line 254 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	full_path = _tmp12_;
#line 255 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp13_ = full_path;
#line 255 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	if (_tmp13_ != NULL) {
#line 2337 "FSpotPhotosTable.c"
		GFile* uri = NULL;
		const gchar* _tmp14_;
		GFile* _tmp15_;
		DataImportsFSpotDbFSpotPhotoRow* _tmp16_;
		GFile* _tmp17_;
		GFile* _tmp18_;
		DataImportsFSpotDbFSpotPhotoRow* _tmp19_;
		GFile* _tmp20_;
		gchar* _tmp21_;
#line 256 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp14_ = full_path;
#line 256 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp15_ = g_file_new_for_uri (_tmp14_);
#line 256 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		uri = _tmp15_;
#line 257 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp16_ = _vala_row;
#line 257 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp17_ = uri;
#line 257 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp18_ = g_file_get_parent (_tmp17_);
#line 257 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_g_object_unref0 (_tmp16_->base_path);
#line 257 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp16_->base_path = _tmp18_;
#line 258 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp19_ = _vala_row;
#line 258 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp20_ = uri;
#line 258 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp21_ = g_file_get_basename (_tmp20_);
#line 258 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_g_free0 (_tmp19_->filename);
#line 258 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp19_->filename = _tmp21_;
#line 255 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_g_object_unref0 (uri);
#line 2375 "FSpotPhotosTable.c"
	}
#line 261 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp22_ = _vala_row;
#line 261 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp23_ = stmt;
#line 261 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp24_ = offset;
#line 261 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp25_ = sqlite3_column_text (_tmp23_, _tmp24_ + 3);
#line 261 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp26_ = g_strdup (_tmp25_);
#line 261 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_g_free0 (_tmp22_->description);
#line 261 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp22_->description = _tmp26_;
#line 262 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp27_ = _vala_row;
#line 262 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp28_ = stmt;
#line 262 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp29_ = offset;
#line 262 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp30_ = sqlite3_column_int64 (_tmp28_, _tmp29_ + 4);
#line 262 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp27_->roll_id = _tmp30_;
#line 263 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp31_ = _vala_row;
#line 263 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp32_ = stmt;
#line 263 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp33_ = offset;
#line 263 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp34_ = sqlite3_column_int64 (_tmp32_, _tmp33_ + 5);
#line 263 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp31_->default_version_id = _tmp34_;
#line 264 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp35_ = _vala_row;
#line 264 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp36_ = stmt;
#line 264 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp37_ = offset;
#line 264 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp38_ = sqlite3_column_int (_tmp36_, _tmp37_ + 6);
#line 264 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp35_->rating = _tmp38_;
#line 265 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp39_ = _vala_row;
#line 265 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp40_ = stmt;
#line 265 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp41_ = offset;
#line 265 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp42_ = sqlite3_column_text (_tmp40_, _tmp41_ + 7);
#line 265 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp43_ = g_strdup (_tmp42_);
#line 265 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_g_free0 (_tmp39_->md5_sum);
#line 265 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp39_->md5_sum = _tmp43_;
#line 249 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_g_free0 (full_path);
#line 249 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	if (row) {
#line 249 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		*row = _vala_row;
#line 2441 "FSpotPhotosTable.c"
	} else {
#line 249 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_g_object_unref0 (_vala_row);
#line 2445 "FSpotPhotosTable.c"
	}
}


static void data_imports_fspot_db_fspot_photos_v16_behavior_class_init (DataImportsFSpotDbFSpotPhotosV16BehaviorClass * klass) {
#line 228 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	data_imports_fspot_db_fspot_photos_v16_behavior_parent_class = g_type_class_peek_parent (klass);
#line 228 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	G_OBJECT_CLASS (klass)->finalize = data_imports_fspot_db_fspot_photos_v16_behavior_finalize;
#line 2455 "FSpotPhotosTable.c"
}


static void data_imports_fspot_db_fspot_photos_v16_behavior_data_imports_fspot_db_fspot_table_behavior_interface_init (DataImportsFSpotDbFSpotTableBehaviorIface * iface) {
#line 228 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	data_imports_fspot_db_fspot_photos_v16_behavior_data_imports_fspot_db_fspot_table_behavior_parent_iface = g_type_interface_peek_parent (iface);
#line 228 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	iface->get_table_name = (gchar* (*) (DataImportsFSpotDbFSpotTableBehavior *)) data_imports_fspot_db_fspot_photos_v16_behavior_real_get_table_name;
#line 228 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	iface->list_columns = (gchar** (*) (DataImportsFSpotDbFSpotTableBehavior *, int*)) data_imports_fspot_db_fspot_photos_v16_behavior_real_list_columns;
#line 228 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	iface->build_row = (void (*) (DataImportsFSpotDbFSpotTableBehavior *, sqlite3_stmt*, gpointer*, gint)) data_imports_fspot_db_fspot_photos_v16_behavior_real_build_row;
#line 2468 "FSpotPhotosTable.c"
}


static void data_imports_fspot_db_fspot_photos_v16_behavior_instance_init (DataImportsFSpotDbFSpotPhotosV16Behavior * self) {
}


static void data_imports_fspot_db_fspot_photos_v16_behavior_finalize (GObject * obj) {
	DataImportsFSpotDbFSpotPhotosV16Behavior * self;
#line 228 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V16_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV16Behavior);
#line 228 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	G_OBJECT_CLASS (data_imports_fspot_db_fspot_photos_v16_behavior_parent_class)->finalize (obj);
#line 2482 "FSpotPhotosTable.c"
}


GType data_imports_fspot_db_fspot_photos_v16_behavior_get_type (void) {
	static volatile gsize data_imports_fspot_db_fspot_photos_v16_behavior_type_id__volatile = 0;
	if (g_once_init_enter (&data_imports_fspot_db_fspot_photos_v16_behavior_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (DataImportsFSpotDbFSpotPhotosV16BehaviorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) data_imports_fspot_db_fspot_photos_v16_behavior_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (DataImportsFSpotDbFSpotPhotosV16Behavior), 0, (GInstanceInitFunc) data_imports_fspot_db_fspot_photos_v16_behavior_instance_init, NULL };
		static const GInterfaceInfo data_imports_fspot_db_fspot_table_behavior_info = { (GInterfaceInitFunc) data_imports_fspot_db_fspot_photos_v16_behavior_data_imports_fspot_db_fspot_table_behavior_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType data_imports_fspot_db_fspot_photos_v16_behavior_type_id;
		data_imports_fspot_db_fspot_photos_v16_behavior_type_id = g_type_register_static (G_TYPE_OBJECT, "DataImportsFSpotDbFSpotPhotosV16Behavior", &g_define_type_info, 0);
		g_type_add_interface_static (data_imports_fspot_db_fspot_photos_v16_behavior_type_id, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_TABLE_BEHAVIOR, &data_imports_fspot_db_fspot_table_behavior_info);
		g_once_init_leave (&data_imports_fspot_db_fspot_photos_v16_behavior_type_id__volatile, data_imports_fspot_db_fspot_photos_v16_behavior_type_id);
	}
	return data_imports_fspot_db_fspot_photos_v16_behavior_type_id__volatile;
}


static DataImportsFSpotDbFSpotPhotosV17Behavior* data_imports_fspot_db_fspot_photos_v17_behavior_construct (GType object_type) {
	DataImportsFSpotDbFSpotPhotosV17Behavior * self = NULL;
#line 275 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	self = (DataImportsFSpotDbFSpotPhotosV17Behavior*) g_object_new (object_type, NULL);
#line 275 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	return self;
#line 2506 "FSpotPhotosTable.c"
}


static DataImportsFSpotDbFSpotPhotosV17Behavior* data_imports_fspot_db_fspot_photos_v17_behavior_new (void) {
#line 275 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	return data_imports_fspot_db_fspot_photos_v17_behavior_construct (DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V17_BEHAVIOR);
#line 2513 "FSpotPhotosTable.c"
}


DataImportsFSpotDbFSpotPhotosV17Behavior* data_imports_fspot_db_fspot_photos_v17_behavior_get_instance (void) {
	DataImportsFSpotDbFSpotPhotosV17Behavior* result = NULL;
	DataImportsFSpotDbFSpotPhotosV17Behavior* _tmp0_;
	DataImportsFSpotDbFSpotPhotosV17Behavior* _tmp2_;
	DataImportsFSpotDbFSpotPhotosV17Behavior* _tmp3_;
#line 279 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp0_ = data_imports_fspot_db_fspot_photos_v17_behavior_instance;
#line 279 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	if (_tmp0_ == NULL) {
#line 2526 "FSpotPhotosTable.c"
		DataImportsFSpotDbFSpotPhotosV17Behavior* _tmp1_;
#line 280 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp1_ = data_imports_fspot_db_fspot_photos_v17_behavior_new ();
#line 280 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_g_object_unref0 (data_imports_fspot_db_fspot_photos_v17_behavior_instance);
#line 280 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		data_imports_fspot_db_fspot_photos_v17_behavior_instance = _tmp1_;
#line 2534 "FSpotPhotosTable.c"
	}
#line 281 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp2_ = data_imports_fspot_db_fspot_photos_v17_behavior_instance;
#line 281 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 281 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	result = _tmp3_;
#line 281 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	return result;
#line 2544 "FSpotPhotosTable.c"
}


static gchar* data_imports_fspot_db_fspot_photos_v17_behavior_real_get_table_name (DataImportsFSpotDbFSpotTableBehavior* base) {
	DataImportsFSpotDbFSpotPhotosV17Behavior * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 284 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V17_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV17Behavior);
#line 285 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp0_ = g_strdup (DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTOS_TABLE_TABLE_NAME);
#line 285 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	result = _tmp0_;
#line 285 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	return result;
#line 2560 "FSpotPhotosTable.c"
}


static gchar** data_imports_fspot_db_fspot_photos_v17_behavior_real_list_columns (DataImportsFSpotDbFSpotTableBehavior* base, int* result_length1) {
	DataImportsFSpotDbFSpotPhotosV17Behavior * self;
	gchar** result = NULL;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	gchar* _tmp7_;
	gchar* _tmp8_;
	gchar** _tmp9_;
	gchar** _tmp10_;
	gint _tmp10__length1;
#line 288 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V17_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV17Behavior);
#line 289 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp0_ = g_strdup ("id");
#line 289 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp1_ = g_strdup ("time");
#line 289 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp2_ = g_strdup ("base_uri");
#line 289 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp3_ = g_strdup ("filename");
#line 289 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp4_ = g_strdup ("description");
#line 289 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp5_ = g_strdup ("roll_id");
#line 289 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp6_ = g_strdup ("default_version_id");
#line 289 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp7_ = g_strdup ("rating");
#line 289 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp8_ = g_strdup ("md5_sum");
#line 289 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp9_ = g_new0 (gchar*, 9 + 1);
#line 289 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp9_[0] = _tmp0_;
#line 289 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp9_[1] = _tmp1_;
#line 289 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp9_[2] = _tmp2_;
#line 289 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp9_[3] = _tmp3_;
#line 289 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp9_[4] = _tmp4_;
#line 289 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp9_[5] = _tmp5_;
#line 289 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp9_[6] = _tmp6_;
#line 289 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp9_[7] = _tmp7_;
#line 289 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp9_[8] = _tmp8_;
#line 289 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp10_ = _tmp9_;
#line 289 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp10__length1 = 9;
#line 289 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	if (result_length1) {
#line 289 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		*result_length1 = _tmp10__length1;
#line 2627 "FSpotPhotosTable.c"
	}
#line 289 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	result = _tmp10_;
#line 289 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	return result;
#line 2633 "FSpotPhotosTable.c"
}


static void data_imports_fspot_db_fspot_photos_v17_behavior_real_build_row (DataImportsFSpotDbFSpotTableBehavior* base, sqlite3_stmt* stmt, DataImportsFSpotDbFSpotPhotoRow* * row, gint offset) {
	DataImportsFSpotDbFSpotPhotosV17Behavior * self;
	DataImportsFSpotDbFSpotPhotoRow* _vala_row = NULL;
	DataImportsFSpotDbFSpotPhotoRow* _tmp0_;
	DataImportsFSpotDbFSpotPhotoRow* _tmp1_;
	sqlite3_stmt* _tmp2_;
	gint _tmp3_;
	gint64 _tmp4_;
	DataImportsFSpotDbFSpotPhotoRow* _tmp5_;
	sqlite3_stmt* _tmp6_;
	gint _tmp7_;
	gint64 _tmp8_;
	gchar* base_path = NULL;
	sqlite3_stmt* _tmp9_;
	gint _tmp10_;
	const gchar* _tmp11_;
	gchar* _tmp12_;
	gchar* filename = NULL;
	sqlite3_stmt* _tmp13_;
	gint _tmp14_;
	const gchar* _tmp15_;
	gchar* _tmp16_;
	gboolean _tmp17_ = FALSE;
	const gchar* _tmp18_;
	DataImportsFSpotDbFSpotPhotoRow* _tmp26_;
	sqlite3_stmt* _tmp27_;
	gint _tmp28_;
	const gchar* _tmp29_;
	gchar* _tmp30_;
	DataImportsFSpotDbFSpotPhotoRow* _tmp31_;
	sqlite3_stmt* _tmp32_;
	gint _tmp33_;
	gint64 _tmp34_;
	DataImportsFSpotDbFSpotPhotoRow* _tmp35_;
	sqlite3_stmt* _tmp36_;
	gint _tmp37_;
	gint64 _tmp38_;
	DataImportsFSpotDbFSpotPhotoRow* _tmp39_;
	sqlite3_stmt* _tmp40_;
	gint _tmp41_;
	gint _tmp42_;
	DataImportsFSpotDbFSpotPhotoRow* _tmp43_;
	sqlite3_stmt* _tmp44_;
	gint _tmp45_;
	const gchar* _tmp46_;
	gchar* _tmp47_;
#line 293 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V17_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV17Behavior);
#line 293 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	g_return_if_fail (stmt != NULL);
#line 294 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp0_ = data_imports_fspot_db_fspot_photo_row_new ();
#line 294 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_g_object_unref0 (_vala_row);
#line 294 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_vala_row = _tmp0_;
#line 295 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp1_ = _vala_row;
#line 295 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp2_ = stmt;
#line 295 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp3_ = offset;
#line 295 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp4_ = sqlite3_column_int64 (_tmp2_, _tmp3_ + 0);
#line 295 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp1_->photo_id = _tmp4_;
#line 296 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp5_ = _vala_row;
#line 296 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp6_ = stmt;
#line 296 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp7_ = offset;
#line 296 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp8_ = sqlite3_column_int64 (_tmp6_, _tmp7_ + 1);
#line 296 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp5_->time = (time_t) _tmp8_;
#line 298 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp9_ = stmt;
#line 298 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp10_ = offset;
#line 298 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp11_ = sqlite3_column_text (_tmp9_, _tmp10_ + 2);
#line 298 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp12_ = g_strdup (_tmp11_);
#line 298 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	base_path = _tmp12_;
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp13_ = stmt;
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp14_ = offset;
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp15_ = sqlite3_column_text (_tmp13_, _tmp14_ + 3);
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp16_ = g_strdup (_tmp15_);
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	filename = _tmp16_;
#line 300 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp18_ = base_path;
#line 300 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	if (_tmp18_ != NULL) {
#line 2737 "FSpotPhotosTable.c"
		const gchar* _tmp19_;
#line 300 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp19_ = filename;
#line 300 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp17_ = _tmp19_ != NULL;
#line 2743 "FSpotPhotosTable.c"
	} else {
#line 300 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp17_ = FALSE;
#line 2747 "FSpotPhotosTable.c"
	}
#line 300 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	if (_tmp17_) {
#line 2751 "FSpotPhotosTable.c"
		DataImportsFSpotDbFSpotPhotoRow* _tmp20_;
		const gchar* _tmp21_;
		GFile* _tmp22_;
		DataImportsFSpotDbFSpotPhotoRow* _tmp23_;
		const gchar* _tmp24_;
		gchar* _tmp25_;
#line 301 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp20_ = _vala_row;
#line 301 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp21_ = base_path;
#line 301 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp22_ = g_file_new_for_uri (_tmp21_);
#line 301 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_g_object_unref0 (_tmp20_->base_path);
#line 301 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp20_->base_path = _tmp22_;
#line 302 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp23_ = _vala_row;
#line 302 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp24_ = filename;
#line 302 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp25_ = g_strdup (_tmp24_);
#line 302 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_g_free0 (_tmp23_->filename);
#line 302 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp23_->filename = _tmp25_;
#line 2778 "FSpotPhotosTable.c"
	}
#line 305 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp26_ = _vala_row;
#line 305 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp27_ = stmt;
#line 305 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp28_ = offset;
#line 305 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp29_ = sqlite3_column_text (_tmp27_, _tmp28_ + 4);
#line 305 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp30_ = g_strdup (_tmp29_);
#line 305 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_g_free0 (_tmp26_->description);
#line 305 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp26_->description = _tmp30_;
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp31_ = _vala_row;
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp32_ = stmt;
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp33_ = offset;
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp34_ = sqlite3_column_int64 (_tmp32_, _tmp33_ + 5);
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp31_->roll_id = _tmp34_;
#line 307 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp35_ = _vala_row;
#line 307 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp36_ = stmt;
#line 307 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp37_ = offset;
#line 307 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp38_ = sqlite3_column_int64 (_tmp36_, _tmp37_ + 6);
#line 307 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp35_->default_version_id = _tmp38_;
#line 308 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp39_ = _vala_row;
#line 308 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp40_ = stmt;
#line 308 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp41_ = offset;
#line 308 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp42_ = sqlite3_column_int (_tmp40_, _tmp41_ + 7);
#line 308 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp39_->rating = _tmp42_;
#line 309 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp43_ = _vala_row;
#line 309 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp44_ = stmt;
#line 309 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp45_ = offset;
#line 309 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp46_ = sqlite3_column_text (_tmp44_, _tmp45_ + 8);
#line 309 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp47_ = g_strdup (_tmp46_);
#line 309 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_g_free0 (_tmp43_->md5_sum);
#line 309 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp43_->md5_sum = _tmp47_;
#line 293 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_g_free0 (filename);
#line 293 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_g_free0 (base_path);
#line 293 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	if (row) {
#line 293 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		*row = _vala_row;
#line 2846 "FSpotPhotosTable.c"
	} else {
#line 293 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_g_object_unref0 (_vala_row);
#line 2850 "FSpotPhotosTable.c"
	}
}


static void data_imports_fspot_db_fspot_photos_v17_behavior_class_init (DataImportsFSpotDbFSpotPhotosV17BehaviorClass * klass) {
#line 272 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	data_imports_fspot_db_fspot_photos_v17_behavior_parent_class = g_type_class_peek_parent (klass);
#line 272 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	G_OBJECT_CLASS (klass)->finalize = data_imports_fspot_db_fspot_photos_v17_behavior_finalize;
#line 2860 "FSpotPhotosTable.c"
}


static void data_imports_fspot_db_fspot_photos_v17_behavior_data_imports_fspot_db_fspot_table_behavior_interface_init (DataImportsFSpotDbFSpotTableBehaviorIface * iface) {
#line 272 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	data_imports_fspot_db_fspot_photos_v17_behavior_data_imports_fspot_db_fspot_table_behavior_parent_iface = g_type_interface_peek_parent (iface);
#line 272 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	iface->get_table_name = (gchar* (*) (DataImportsFSpotDbFSpotTableBehavior *)) data_imports_fspot_db_fspot_photos_v17_behavior_real_get_table_name;
#line 272 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	iface->list_columns = (gchar** (*) (DataImportsFSpotDbFSpotTableBehavior *, int*)) data_imports_fspot_db_fspot_photos_v17_behavior_real_list_columns;
#line 272 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	iface->build_row = (void (*) (DataImportsFSpotDbFSpotTableBehavior *, sqlite3_stmt*, gpointer*, gint)) data_imports_fspot_db_fspot_photos_v17_behavior_real_build_row;
#line 2873 "FSpotPhotosTable.c"
}


static void data_imports_fspot_db_fspot_photos_v17_behavior_instance_init (DataImportsFSpotDbFSpotPhotosV17Behavior * self) {
}


static void data_imports_fspot_db_fspot_photos_v17_behavior_finalize (GObject * obj) {
	DataImportsFSpotDbFSpotPhotosV17Behavior * self;
#line 272 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V17_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV17Behavior);
#line 272 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	G_OBJECT_CLASS (data_imports_fspot_db_fspot_photos_v17_behavior_parent_class)->finalize (obj);
#line 2887 "FSpotPhotosTable.c"
}


GType data_imports_fspot_db_fspot_photos_v17_behavior_get_type (void) {
	static volatile gsize data_imports_fspot_db_fspot_photos_v17_behavior_type_id__volatile = 0;
	if (g_once_init_enter (&data_imports_fspot_db_fspot_photos_v17_behavior_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (DataImportsFSpotDbFSpotPhotosV17BehaviorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) data_imports_fspot_db_fspot_photos_v17_behavior_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (DataImportsFSpotDbFSpotPhotosV17Behavior), 0, (GInstanceInitFunc) data_imports_fspot_db_fspot_photos_v17_behavior_instance_init, NULL };
		static const GInterfaceInfo data_imports_fspot_db_fspot_table_behavior_info = { (GInterfaceInitFunc) data_imports_fspot_db_fspot_photos_v17_behavior_data_imports_fspot_db_fspot_table_behavior_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType data_imports_fspot_db_fspot_photos_v17_behavior_type_id;
		data_imports_fspot_db_fspot_photos_v17_behavior_type_id = g_type_register_static (G_TYPE_OBJECT, "DataImportsFSpotDbFSpotPhotosV17Behavior", &g_define_type_info, 0);
		g_type_add_interface_static (data_imports_fspot_db_fspot_photos_v17_behavior_type_id, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_TABLE_BEHAVIOR, &data_imports_fspot_db_fspot_table_behavior_info);
		g_once_init_leave (&data_imports_fspot_db_fspot_photos_v17_behavior_type_id__volatile, data_imports_fspot_db_fspot_photos_v17_behavior_type_id);
	}
	return data_imports_fspot_db_fspot_photos_v17_behavior_type_id__volatile;
}


static DataImportsFSpotDbFSpotPhotosV18Behavior* data_imports_fspot_db_fspot_photos_v18_behavior_construct (GType object_type) {
	DataImportsFSpotDbFSpotPhotosV18Behavior * self = NULL;
#line 317 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	self = (DataImportsFSpotDbFSpotPhotosV18Behavior*) g_object_new (object_type, NULL);
#line 317 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	return self;
#line 2911 "FSpotPhotosTable.c"
}


static DataImportsFSpotDbFSpotPhotosV18Behavior* data_imports_fspot_db_fspot_photos_v18_behavior_new (void) {
#line 317 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	return data_imports_fspot_db_fspot_photos_v18_behavior_construct (DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V18_BEHAVIOR);
#line 2918 "FSpotPhotosTable.c"
}


DataImportsFSpotDbFSpotPhotosV18Behavior* data_imports_fspot_db_fspot_photos_v18_behavior_get_instance (void) {
	DataImportsFSpotDbFSpotPhotosV18Behavior* result = NULL;
	DataImportsFSpotDbFSpotPhotosV18Behavior* _tmp0_;
	DataImportsFSpotDbFSpotPhotosV18Behavior* _tmp2_;
	DataImportsFSpotDbFSpotPhotosV18Behavior* _tmp3_;
#line 321 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp0_ = data_imports_fspot_db_fspot_photos_v18_behavior_instance;
#line 321 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	if (_tmp0_ == NULL) {
#line 2931 "FSpotPhotosTable.c"
		DataImportsFSpotDbFSpotPhotosV18Behavior* _tmp1_;
#line 322 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp1_ = data_imports_fspot_db_fspot_photos_v18_behavior_new ();
#line 322 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_g_object_unref0 (data_imports_fspot_db_fspot_photos_v18_behavior_instance);
#line 322 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		data_imports_fspot_db_fspot_photos_v18_behavior_instance = _tmp1_;
#line 2939 "FSpotPhotosTable.c"
	}
#line 323 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp2_ = data_imports_fspot_db_fspot_photos_v18_behavior_instance;
#line 323 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 323 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	result = _tmp3_;
#line 323 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	return result;
#line 2949 "FSpotPhotosTable.c"
}


static gchar* data_imports_fspot_db_fspot_photos_v18_behavior_real_get_table_name (DataImportsFSpotDbFSpotTableBehavior* base) {
	DataImportsFSpotDbFSpotPhotosV18Behavior * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 326 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V18_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV18Behavior);
#line 327 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp0_ = g_strdup (DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTOS_TABLE_TABLE_NAME);
#line 327 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	result = _tmp0_;
#line 327 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	return result;
#line 2965 "FSpotPhotosTable.c"
}


static gchar** data_imports_fspot_db_fspot_photos_v18_behavior_real_list_columns (DataImportsFSpotDbFSpotTableBehavior* base, int* result_length1) {
	DataImportsFSpotDbFSpotPhotosV18Behavior * self;
	gchar** result = NULL;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	gchar* _tmp7_;
	gchar** _tmp8_;
	gchar** _tmp9_;
	gint _tmp9__length1;
#line 330 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V18_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV18Behavior);
#line 331 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp0_ = g_strdup ("id");
#line 331 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp1_ = g_strdup ("time");
#line 331 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp2_ = g_strdup ("base_uri");
#line 331 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp3_ = g_strdup ("filename");
#line 331 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp4_ = g_strdup ("description");
#line 331 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp5_ = g_strdup ("roll_id");
#line 331 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp6_ = g_strdup ("default_version_id");
#line 331 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp7_ = g_strdup ("rating");
#line 331 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp8_ = g_new0 (gchar*, 8 + 1);
#line 331 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp8_[0] = _tmp0_;
#line 331 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp8_[1] = _tmp1_;
#line 331 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp8_[2] = _tmp2_;
#line 331 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp8_[3] = _tmp3_;
#line 331 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp8_[4] = _tmp4_;
#line 331 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp8_[5] = _tmp5_;
#line 331 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp8_[6] = _tmp6_;
#line 331 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp8_[7] = _tmp7_;
#line 331 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp9_ = _tmp8_;
#line 331 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp9__length1 = 8;
#line 331 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	if (result_length1) {
#line 331 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		*result_length1 = _tmp9__length1;
#line 3027 "FSpotPhotosTable.c"
	}
#line 331 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	result = _tmp9_;
#line 331 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	return result;
#line 3033 "FSpotPhotosTable.c"
}


static void data_imports_fspot_db_fspot_photos_v18_behavior_real_build_row (DataImportsFSpotDbFSpotTableBehavior* base, sqlite3_stmt* stmt, DataImportsFSpotDbFSpotPhotoRow* * row, gint offset) {
	DataImportsFSpotDbFSpotPhotosV18Behavior * self;
	DataImportsFSpotDbFSpotPhotoRow* _vala_row = NULL;
	DataImportsFSpotDbFSpotPhotoRow* _tmp0_;
	DataImportsFSpotDbFSpotPhotoRow* _tmp1_;
	sqlite3_stmt* _tmp2_;
	gint _tmp3_;
	gint64 _tmp4_;
	DataImportsFSpotDbFSpotPhotoRow* _tmp5_;
	sqlite3_stmt* _tmp6_;
	gint _tmp7_;
	gint64 _tmp8_;
	gchar* base_path = NULL;
	sqlite3_stmt* _tmp9_;
	gint _tmp10_;
	const gchar* _tmp11_;
	gchar* _tmp12_;
	gchar* filename = NULL;
	sqlite3_stmt* _tmp13_;
	gint _tmp14_;
	const gchar* _tmp15_;
	gchar* _tmp16_;
	gboolean _tmp17_ = FALSE;
	const gchar* _tmp18_;
	DataImportsFSpotDbFSpotPhotoRow* _tmp26_;
	sqlite3_stmt* _tmp27_;
	gint _tmp28_;
	const gchar* _tmp29_;
	gchar* _tmp30_;
	DataImportsFSpotDbFSpotPhotoRow* _tmp31_;
	sqlite3_stmt* _tmp32_;
	gint _tmp33_;
	gint64 _tmp34_;
	DataImportsFSpotDbFSpotPhotoRow* _tmp35_;
	sqlite3_stmt* _tmp36_;
	gint _tmp37_;
	gint64 _tmp38_;
	DataImportsFSpotDbFSpotPhotoRow* _tmp39_;
	sqlite3_stmt* _tmp40_;
	gint _tmp41_;
	gint _tmp42_;
	DataImportsFSpotDbFSpotPhotoRow* _tmp43_;
	gchar* _tmp44_;
#line 335 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V18_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV18Behavior);
#line 335 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	g_return_if_fail (stmt != NULL);
#line 336 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp0_ = data_imports_fspot_db_fspot_photo_row_new ();
#line 336 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_g_object_unref0 (_vala_row);
#line 336 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_vala_row = _tmp0_;
#line 337 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp1_ = _vala_row;
#line 337 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp2_ = stmt;
#line 337 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp3_ = offset;
#line 337 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp4_ = sqlite3_column_int64 (_tmp2_, _tmp3_ + 0);
#line 337 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp1_->photo_id = _tmp4_;
#line 338 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp5_ = _vala_row;
#line 338 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp6_ = stmt;
#line 338 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp7_ = offset;
#line 338 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp8_ = sqlite3_column_int64 (_tmp6_, _tmp7_ + 1);
#line 338 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp5_->time = (time_t) _tmp8_;
#line 340 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp9_ = stmt;
#line 340 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp10_ = offset;
#line 340 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp11_ = sqlite3_column_text (_tmp9_, _tmp10_ + 2);
#line 340 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp12_ = g_strdup (_tmp11_);
#line 340 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	base_path = _tmp12_;
#line 341 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp13_ = stmt;
#line 341 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp14_ = offset;
#line 341 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp15_ = sqlite3_column_text (_tmp13_, _tmp14_ + 3);
#line 341 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp16_ = g_strdup (_tmp15_);
#line 341 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	filename = _tmp16_;
#line 342 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp18_ = base_path;
#line 342 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	if (_tmp18_ != NULL) {
#line 3134 "FSpotPhotosTable.c"
		const gchar* _tmp19_;
#line 342 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp19_ = filename;
#line 342 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp17_ = _tmp19_ != NULL;
#line 3140 "FSpotPhotosTable.c"
	} else {
#line 342 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp17_ = FALSE;
#line 3144 "FSpotPhotosTable.c"
	}
#line 342 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	if (_tmp17_) {
#line 3148 "FSpotPhotosTable.c"
		DataImportsFSpotDbFSpotPhotoRow* _tmp20_;
		const gchar* _tmp21_;
		GFile* _tmp22_;
		DataImportsFSpotDbFSpotPhotoRow* _tmp23_;
		const gchar* _tmp24_;
		gchar* _tmp25_;
#line 343 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp20_ = _vala_row;
#line 343 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp21_ = base_path;
#line 343 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp22_ = g_file_new_for_uri (_tmp21_);
#line 343 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_g_object_unref0 (_tmp20_->base_path);
#line 343 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp20_->base_path = _tmp22_;
#line 344 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp23_ = _vala_row;
#line 344 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp24_ = filename;
#line 344 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp25_ = g_strdup (_tmp24_);
#line 344 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_g_free0 (_tmp23_->filename);
#line 344 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_tmp23_->filename = _tmp25_;
#line 3175 "FSpotPhotosTable.c"
	}
#line 347 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp26_ = _vala_row;
#line 347 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp27_ = stmt;
#line 347 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp28_ = offset;
#line 347 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp29_ = sqlite3_column_text (_tmp27_, _tmp28_ + 4);
#line 347 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp30_ = g_strdup (_tmp29_);
#line 347 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_g_free0 (_tmp26_->description);
#line 347 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp26_->description = _tmp30_;
#line 348 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp31_ = _vala_row;
#line 348 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp32_ = stmt;
#line 348 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp33_ = offset;
#line 348 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp34_ = sqlite3_column_int64 (_tmp32_, _tmp33_ + 5);
#line 348 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp31_->roll_id = _tmp34_;
#line 349 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp35_ = _vala_row;
#line 349 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp36_ = stmt;
#line 349 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp37_ = offset;
#line 349 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp38_ = sqlite3_column_int64 (_tmp36_, _tmp37_ + 6);
#line 349 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp35_->default_version_id = _tmp38_;
#line 350 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp39_ = _vala_row;
#line 350 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp40_ = stmt;
#line 350 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp41_ = offset;
#line 350 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp42_ = sqlite3_column_int (_tmp40_, _tmp41_ + 7);
#line 350 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp39_->rating = _tmp42_;
#line 351 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp43_ = _vala_row;
#line 351 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp44_ = g_strdup ("");
#line 351 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_g_free0 (_tmp43_->md5_sum);
#line 351 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_tmp43_->md5_sum = _tmp44_;
#line 335 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_g_free0 (filename);
#line 335 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	_g_free0 (base_path);
#line 335 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	if (row) {
#line 335 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		*row = _vala_row;
#line 3237 "FSpotPhotosTable.c"
	} else {
#line 335 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
		_g_object_unref0 (_vala_row);
#line 3241 "FSpotPhotosTable.c"
	}
}


static void data_imports_fspot_db_fspot_photos_v18_behavior_class_init (DataImportsFSpotDbFSpotPhotosV18BehaviorClass * klass) {
#line 314 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	data_imports_fspot_db_fspot_photos_v18_behavior_parent_class = g_type_class_peek_parent (klass);
#line 314 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	G_OBJECT_CLASS (klass)->finalize = data_imports_fspot_db_fspot_photos_v18_behavior_finalize;
#line 3251 "FSpotPhotosTable.c"
}


static void data_imports_fspot_db_fspot_photos_v18_behavior_data_imports_fspot_db_fspot_table_behavior_interface_init (DataImportsFSpotDbFSpotTableBehaviorIface * iface) {
#line 314 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	data_imports_fspot_db_fspot_photos_v18_behavior_data_imports_fspot_db_fspot_table_behavior_parent_iface = g_type_interface_peek_parent (iface);
#line 314 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	iface->get_table_name = (gchar* (*) (DataImportsFSpotDbFSpotTableBehavior *)) data_imports_fspot_db_fspot_photos_v18_behavior_real_get_table_name;
#line 314 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	iface->list_columns = (gchar** (*) (DataImportsFSpotDbFSpotTableBehavior *, int*)) data_imports_fspot_db_fspot_photos_v18_behavior_real_list_columns;
#line 314 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	iface->build_row = (void (*) (DataImportsFSpotDbFSpotTableBehavior *, sqlite3_stmt*, gpointer*, gint)) data_imports_fspot_db_fspot_photos_v18_behavior_real_build_row;
#line 3264 "FSpotPhotosTable.c"
}


static void data_imports_fspot_db_fspot_photos_v18_behavior_instance_init (DataImportsFSpotDbFSpotPhotosV18Behavior * self) {
}


static void data_imports_fspot_db_fspot_photos_v18_behavior_finalize (GObject * obj) {
	DataImportsFSpotDbFSpotPhotosV18Behavior * self;
#line 314 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V18_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV18Behavior);
#line 314 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotosTable.vala"
	G_OBJECT_CLASS (data_imports_fspot_db_fspot_photos_v18_behavior_parent_class)->finalize (obj);
#line 3278 "FSpotPhotosTable.c"
}


GType data_imports_fspot_db_fspot_photos_v18_behavior_get_type (void) {
	static volatile gsize data_imports_fspot_db_fspot_photos_v18_behavior_type_id__volatile = 0;
	if (g_once_init_enter (&data_imports_fspot_db_fspot_photos_v18_behavior_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (DataImportsFSpotDbFSpotPhotosV18BehaviorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) data_imports_fspot_db_fspot_photos_v18_behavior_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (DataImportsFSpotDbFSpotPhotosV18Behavior), 0, (GInstanceInitFunc) data_imports_fspot_db_fspot_photos_v18_behavior_instance_init, NULL };
		static const GInterfaceInfo data_imports_fspot_db_fspot_table_behavior_info = { (GInterfaceInitFunc) data_imports_fspot_db_fspot_photos_v18_behavior_data_imports_fspot_db_fspot_table_behavior_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType data_imports_fspot_db_fspot_photos_v18_behavior_type_id;
		data_imports_fspot_db_fspot_photos_v18_behavior_type_id = g_type_register_static (G_TYPE_OBJECT, "DataImportsFSpotDbFSpotPhotosV18Behavior", &g_define_type_info, 0);
		g_type_add_interface_static (data_imports_fspot_db_fspot_photos_v18_behavior_type_id, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_TABLE_BEHAVIOR, &data_imports_fspot_db_fspot_table_behavior_info);
		g_once_init_leave (&data_imports_fspot_db_fspot_photos_v18_behavior_type_id__volatile, data_imports_fspot_db_fspot_photos_v18_behavior_type_id);
	}
	return data_imports_fspot_db_fspot_photos_v18_behavior_type_id__volatile;
}



